@@ -1,4 +1,4 @@
-/* 
+/*
  * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@
 DWIDGET_USE_NAMESPACE
 
 
-static const char* vs_blend = R"(
+static const char *vs_blend = R"(
 attribute vec2 position;
 attribute vec2 vTexCoord;
 
@@ -162,6 +162,7 @@ namespace dmr {
             context()->swapBuffers(context()->surface());
             doneCurrent();
         } else {
+            mpv_render_context_update(_render_ctx);
             update();
         }
     }
@@ -169,18 +170,13 @@ namespace dmr {
     void MpvGLWidget::onFrameSwapped()
     {
         //qDebug() << "frame swapped";
-        mpv_opengl_cb_report_flip(_gl_ctx, 0);
+        mpv_render_context_report_swap(_render_ctx);
     }
 
     MpvGLWidget::MpvGLWidget(QWidget *parent, mpv::qt::Handle h)
         :QOpenGLWidget(parent), _handle(h) { 
         setUpdateBehavior(QOpenGLWidget::NoPartialUpdate);
 
-        _gl_ctx = (mpv_opengl_cb_context*) mpv_get_sub_api(h, MPV_SUB_API_OPENGL_CB);
-        if (!_gl_ctx) {
-            std::runtime_error("can not init mpv gl");
-        }
-        mpv_opengl_cb_set_update_callback(_gl_ctx, gl_update_callback, this);
         connect(this, &QOpenGLWidget::frameSwapped, 
                 this, &MpvGLWidget::onFrameSwapped, Qt::DirectConnection);
 
@@ -196,6 +192,10 @@ namespace dmr {
             _darkTex->destroy();
             delete _darkTex;
         }
+//        if (_darkTexbac) {
+//            _darkTexbac->destroy();
+//            delete _darkTexbac;
+//        }
         if (_lightTex) {
             _lightTex->destroy();
             delete _lightTex;
@@ -217,12 +217,11 @@ namespace dmr {
 
         if (_fbo) delete _fbo;
 
-        if (_gl_ctx)
-            mpv_opengl_cb_set_update_callback(_gl_ctx, NULL, NULL);
+        if (_render_ctx) mpv_render_context_set_update_callback(_render_ctx, NULL, NULL);
         // Until this call is done, we need to make sure the player remains
         // alive. This is done implicitly with the mpv::qt::Handle instance
         // in this class.
-        mpv_opengl_cb_uninit_gl(_gl_ctx);
+        mpv_render_context_free(_render_ctx);
         doneCurrent();
     }
 
@@ -266,6 +265,8 @@ namespace dmr {
         _vao.create();
         _vao.bind();
 
+//        _darkTexbac = new QOpenGLTexture(bg_dark_bac, QOpenGLTexture::DontGenerateMipMaps);
+//        _darkTexbac->setMinificationFilter(QOpenGLTexture::Linear);
         _darkTex = new QOpenGLTexture(bg_dark, QOpenGLTexture::DontGenerateMipMaps);
         _darkTex->setMinificationFilter(QOpenGLTexture::Linear);
         _lightTex = new QOpenGLTexture(bg_light, QOpenGLTexture::DontGenerateMipMaps);
@@ -312,8 +313,35 @@ namespace dmr {
 
     void MpvGLWidget::prepareSplashImages()
     {
-        bg_dark = utils::LoadHiDPIImage(":/resources/icons/dark/init-splash.svg");
-        bg_light = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
+//        bg_dark = utils::LoadHiDPIImage(":/resources/icons/dark/init-splash.svg");
+//        bg_light = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
+
+        QPixmap pixmap/*(":/resources/icons/dark/init-splash-bac.svg")*/;
+        QImage img=utils::LoadHiDPIImage(":/resources/icons/dark/init-splash-bac.svg");
+        pixmap=pixmap.fromImage(img);
+        QPixmap pixmap2/*(":/resources/icons/dark/init-splash.svg")*/;
+        QImage img1=utils::LoadHiDPIImage(":/resources/icons/dark/init-splash.svg");
+        pixmap2=pixmap2.fromImage(img1);
+        QPainter p(&pixmap);
+//        p.drawPixmap((pixmap.width()-pixmap2.width())/2,(pixmap.height()-pixmap2.height())/2,pixmap2);
+        p.drawPixmap(98,127,pixmap2);
+        bg_dark=pixmap.toImage();
+        bg_dark.setDevicePixelRatio(qApp->devicePixelRatio());
+
+        QPixmap pixmap3;
+        QImage image(pixmap.size(),QImage::Format_Alpha8);
+        image.fill(QColor(0, 0, 0, 0));
+        image.setDevicePixelRatio(qApp->devicePixelRatio());
+//        QImage image=utils::LoadHiDPIImage(":/resources/icons/light/init-light-bac.svg");
+        pixmap3=pixmap3.fromImage(image);
+        QPixmap pixmap4/*(":/resources/icons/dark/init-splash.svg")*/;
+        QImage img2=utils::LoadHiDPIImage(":/resources/icons/dark/init-splash.svg");
+        pixmap4=pixmap4.fromImage(img2);
+        QPainter p1(&pixmap3);
+//        p1.drawPixmap((pixmap.width()-pixmap4.width())/2,(pixmap.height()-pixmap4.height())/2,pixmap4);
+        p1.drawPixmap(98,127,pixmap4);
+        bg_light=pixmap3.toImage();
+        bg_light.setDevicePixelRatio(qApp->devicePixelRatio());
     }
 
     void MpvGLWidget::initializeGL() 
@@ -322,7 +350,11 @@ namespace dmr {
         //f->glEnable(GL_BLEND);
         //f->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         float a = 16.0 / 255.0;
-        if (qApp->theme() != "dark") a = 252.0 / 255.0;
+
+//        if (qApp->theme() != "dark") a = 252.0 / 255.0;
+        if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()){
+            a = 252.0 / 255.0;
+        }
         f->glClearColor(a, a, a, 1.0);
 
 
@@ -342,8 +374,27 @@ namespace dmr {
 #endif
 #endif
 
-        if (mpv_opengl_cb_init_gl(_gl_ctx, "GL_MP_MPGetNativeDisplay", get_proc_address, NULL) < 0)
-            throw std::runtime_error("could not initialize OpenGL");
+        mpv_opengl_init_params gl_init_params = { get_proc_address, NULL, NULL };
+        int adv_control = 1;
+        mpv_render_param params[] = {
+            {MPV_RENDER_PARAM_API_TYPE, const_cast<char*>(MPV_RENDER_API_TYPE_OPENGL)},
+            {MPV_RENDER_PARAM_OPENGL_INIT_PARAMS, &gl_init_params},
+
+            /*
+             *    which saves a copy per video frame ("vd-lavc-dr" option
+             *    needs to be enabled, and the rendering backend as well as the
+             *    underlying GPU API/driver needs to have support for it).
+             **/
+            //{MPV_RENDER_PARAM_ADVANCED_CONTROL, &adv_control},
+            {MPV_RENDER_PARAM_X11_DISPLAY, reinterpret_cast<void*>(QX11Info::display())},
+            {MPV_RENDER_PARAM_INVALID, nullptr}
+        };
+        if (mpv_render_context_create(&_render_ctx, _handle, params) < 0) {
+            std::runtime_error("can not init mpv gl");
+        }
+
+        mpv_render_context_set_update_callback(_render_ctx, gl_update_callback,
+                reinterpret_cast<void*>(this));
     }
 
     void MpvGLWidget::updateMovieFbo()
@@ -569,15 +620,38 @@ namespace dmr {
 
             auto dpr = qApp->devicePixelRatio();
             QSize scaled = size() * dpr;
+            int flip = 1;
 
             if (!_doRoundedClipping) {
-                mpv_opengl_cb_draw(_gl_ctx, defaultFramebufferObject(), scaled.width(), -scaled.height());
+                mpv_opengl_fbo fbo {
+                    static_cast<int>(defaultFramebufferObject()), scaled.width(), scaled.height(), 0
+                };
+
+                mpv_render_param params[] = {
+                    {MPV_RENDER_PARAM_OPENGL_FBO, &fbo},
+                    {MPV_RENDER_PARAM_FLIP_Y, &flip},
+                    {MPV_RENDER_PARAM_INVALID, nullptr}
+                };
+
+                mpv_render_context_render(_render_ctx, params);
             } else {
                 f->glEnable(GL_BLEND);
                 f->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
                 _fbo->bind();
-                mpv_opengl_cb_draw(_gl_ctx, _fbo->handle(), scaled.width(), -scaled.height());
+
+                mpv_opengl_fbo fbo {
+                    static_cast<int>(_fbo->handle()), scaled.width(), scaled.height(), 0
+                };
+
+                mpv_render_param params[] = {
+                    {MPV_RENDER_PARAM_OPENGL_FBO, &fbo},
+                    {MPV_RENDER_PARAM_FLIP_Y, &flip},
+                    {MPV_RENDER_PARAM_INVALID, nullptr}
+                };
+
+                mpv_render_context_render(_render_ctx, params);
+
                 _fbo->release();
 
                 {
@@ -632,31 +706,39 @@ namespace dmr {
         } else {
             f->glEnable(GL_BLEND);
             f->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-            auto clr = QColor(16, 16, 16, 255);
-            float a = 16.0 / 255.0;
-            if (qApp->theme() != "dark") {
+            auto clr = QColor(37, 37, 37, 255);
+            float a = 37.0 / 255.0;
+//            if (qApp->theme() != "dark") {
+//                clr = QColor(252, 252, 252, 255);
+//                a = 252.0 / 255.0;
+//            }
+            if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()){
                 clr = QColor(252, 252, 252, 255);
                 a = 252.0 / 255.0;
             }
             f->glClearColor(a, a, a, 1.0);
             f->glClear(GL_COLOR_BUFFER_BIT);
 
-            {
-                QOpenGLVertexArrayObject::Binder vaoBind(&_vao);
-                _vbo.bind();
-                _glProg->bind();
-                _glProg->setUniformValue("bg", clr);
+            for(int i = 0;i < 2 ;i ++){
+                {
+                    QOpenGLVertexArrayObject::Binder vaoBind(&_vao);
+                    _vbo.bind();
+                    _glProg->bind();
+                    _glProg->setUniformValue("bg", clr);
 
-                QOpenGLTexture *tex = _lightTex;
-                if (qApp->theme() == "dark") {
-                    tex = _darkTex;
+                    QOpenGLTexture *tex = _lightTex;
+                    DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
+                    //                if (qApp->theme() == "dark") {
+                    if (themeType == DGuiApplicationHelper::DarkType) {
+                        tex = _darkTex;
+                    }
+                    tex->bind();
+                    f->glActiveTexture(GL_TEXTURE0);
+                    f->glDrawArrays(GL_TRIANGLES, 0, 6);
+                    tex->release();
+                    _glProg->release();
+                    _vbo.release();
                 }
-                f->glActiveTexture(GL_TEXTURE0);
-                tex->bind();
-                f->glDrawArrays(GL_TRIANGLES, 0, 6);
-                tex->release();
-                _glProg->release();
-                _vbo.release();
             }
 
             if (_doRoundedClipping) {
