@@ -60,10 +60,13 @@ ShortcutManager::ShortcutManager()
         {"seek_backward", ActionFactory::ActionKind::SeekBackward},
         {"seek_backward_large", ActionFactory::ActionKind::SeekBackwardLarge},
         {"fullscreen", ActionFactory::ActionKind::ToggleFullscreen},
+        {"exitfullscreen", ActionFactory::ActionKind::QuitFullscreen},
         {"playlist", ActionFactory::ActionKind::TogglePlaylist},
         {"accel", ActionFactory::ActionKind::AccelPlayback},
         {"decel", ActionFactory::ActionKind::DecelPlayback},
         {"reset", ActionFactory::ActionKind::ResetPlayback},
+        {"delete_from_playlist", ActionFactory::ActionKind::PlaylistRemoveItem},
+        {"movie_info", ActionFactory::ActionKind::MovieInfo},
 
         {"mini", ActionFactory::ActionKind::ToggleMiniMode},
         {"vol_up", ActionFactory::ActionKind::VolumeUp},
@@ -103,14 +106,30 @@ ShortcutManager::ShortcutManager()
 
             sk.remove(0, sk.lastIndexOf('.') + 1);
 
-            QStringList keyseqs = val.toStringList();
-            Q_ASSERT (keyseqs.length() == 2);
-            auto modifier = static_cast<Qt::KeyboardModifiers>(keyseqs.value(0).toInt());
-            auto key = static_cast<Qt::Key>(keyseqs.value(1).toInt());
+//            QStringList keyseqs = val.toStringList();
+//            auto modifier = static_cast<Qt::KeyboardModifiers>(keyseqs.value(0).toInt());
+//            auto key = static_cast<Qt::Key>(keyseqs.value(1).toInt());
+
+            qDebug() << "update binding" << sk << QKeySequence(val.toStringList().at(0));
+            QString strKey = QKeySequence(val.toStringList().at(0)).toString();
+            if (strKey.contains("Return")) {
+                _map[QKeySequence(val.toStringList().at(0))] = _keyToAction[sk];
+                strKey = QString("%1Num+Enter").arg(strKey.remove("Return"));
+                _map[strKey] = _keyToAction[sk];
+                qDebug() << val << QKeySequence(strKey) << strKey;
+
+                _map.remove(strKey);
+                _map[strKey] = _keyToAction[sk];
+
+            } else if (strKey.contains("Num+Enter")) {
+                _map[QKeySequence(val.toStringList().at(0))] = _keyToAction[sk];
+                strKey = QString("%1Return").arg(strKey.remove("Num+Enter"));
+                _map[strKey] = _keyToAction[sk];
+                qDebug() << val << QKeySequence(strKey) << strKey;
+            }
 
-            qDebug() << "update binding" << sk << QKeySequence(modifier + key);
             _map.remove(_map.key(_keyToAction[sk]));
-            _map[QKeySequence(modifier + key)] = _keyToAction[sk];
+            _map[QKeySequence(val.toStringList().at(0))] = _keyToAction[sk];
             emit bindingsChanged();
         });
 }
@@ -129,19 +148,38 @@ void ShortcutManager::toggleGroupShortcuts(GroupPtr grp, bool on)
     std::for_each(sub.begin(), sub.end(), [=](OptionPtr opt) {
         if (opt->viewType() != "shortcut") return;
 
-        QStringList keyseqs = opt->value().toStringList();
-        Q_ASSERT (keyseqs.length() == 2);
-        auto modifier = static_cast<Qt::KeyboardModifiers>(keyseqs.value(0).toInt());
-        auto key = static_cast<Qt::Key>(keyseqs.value(1).toInt());
+//        QStringList keyseqs = opt->value().toStringList();
+//        auto modifier = static_cast<Qt::KeyboardModifiers>(keyseqs.value(0).toInt());
+//        auto key = static_cast<Qt::Key>(keyseqs.value(1).toInt());
 
         QString sk = opt->key();
         sk.remove(0, sk.lastIndexOf('.') + 1);
-        qDebug() << opt->name() << QKeySequence(modifier + key);
+        //qDebug() << opt->name()
+        //         << QKeySequence(opt->value().toStringList().at(0))
+        //         << QKeySequence(opt->value().toStringList().at(0)).toString();
+        QString strKey = QKeySequence(opt->value().toStringList().at(0)).toString();
+
+        if (strKey.contains("Return")) {
+            _map[QKeySequence(opt->value().toStringList().at(0))] = _keyToAction[sk];
+//                strKey = QString("%1Return, %1Num+Enter").arg(strKey.remove("Return"));
+            strKey = QString("%1Num+Enter").arg(strKey.remove("Return"));
+            _map[strKey] = _keyToAction[sk];
+            //qDebug() << opt->name() << QKeySequence(strKey) << strKey;
+
+        } else if (strKey.contains("Num+Enter")) {
+            _map[QKeySequence(opt->value().toStringList().at(0))] = _keyToAction[sk];
+//                strKey = QString("%1Return, %1Num+Enter").arg(strKey.remove("Num+Enter"));
+            strKey = QString("%1Return").arg(strKey.remove("Num+Enter"));
+            _map[strKey] = _keyToAction[sk];
+            //qDebug() << opt->name() << QKeySequence(strKey) << strKey;
+        }
 
         if (on) {
-            _map[QKeySequence(modifier + key)] = _keyToAction[sk];
+            _map[strKey] = _keyToAction[sk];
+            //qDebug() << opt->name() << QKeySequence(strKey) << strKey;
+            _map[QKeySequence(opt->value().toStringList().at(0))] = _keyToAction[sk];
         } else {
-            _map.remove(QKeySequence(modifier + key));
+            _map.remove(QKeySequence(opt->value().toStringList().at(0)));
         }
     });
 }
@@ -150,13 +188,14 @@ void ShortcutManager::buildBindingsFromSettings()
 {
     _map.clear();
     // default builtins 
-    _map.insert(QKeySequence(Qt::Key_Left), ActionFactory::SeekBackward);
-    _map.insert(QKeySequence(Qt::Key_Left + Qt::SHIFT), ActionFactory::SeekBackwardLarge);
-    _map.insert(QKeySequence(Qt::Key_Right), ActionFactory::SeekForward);
-    _map.insert(QKeySequence(Qt::Key_Right + Qt::SHIFT), ActionFactory::SeekForwardLarge);
-    _map.insert(QKeySequence(Qt::Key_Space), ActionFactory::TogglePause);
-    _map.insert(QKeySequence(Qt::Key_Escape), ActionFactory::QuitFullscreen);
+//    _map.insert(QKeySequence(Qt::Key_Left), ActionFactory::SeekBackward);
+//    _map.insert(QKeySequence(Qt::Key_Left + Qt::SHIFT), ActionFactory::SeekBackwardLarge);
+//    _map.insert(QKeySequence(Qt::Key_Right), ActionFactory::SeekForward);
+//    _map.insert(QKeySequence(Qt::Key_Right + Qt::SHIFT), ActionFactory::SeekForwardLarge);
+//    _map.insert(QKeySequence(Qt::Key_Space), ActionFactory::TogglePause);
+//    _map.insert(QKeySequence(Qt::Key_Escape), ActionFactory::QuitFullscreen);
     _map.insert(QKeySequence(Qt::Key_Slash + Qt::CTRL + Qt::SHIFT), ActionFactory::ViewShortcut);
+    _map.insert(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_H), ActionFactory::Hwdec);
 
     QPointer<DSettingsGroup> shortcuts = Settings::get().shortcuts();
 
@@ -192,20 +231,53 @@ QString ShortcutManager::toJson()
             if (opt->viewType() != "shortcut") return;
 
             QStringList keyseqs = opt->value().toStringList();
-            Q_ASSERT (keyseqs.length() == 2);
-            auto modifier = static_cast<Qt::KeyboardModifiers>(keyseqs.value(0).toInt());
-            auto key = static_cast<Qt::Key>(keyseqs.value(1).toInt());
+//            auto modifier = static_cast<Qt::KeyboardModifiers>(keyseqs.value(0).toInt());
+//            auto key = static_cast<Qt::Key>(keyseqs.value(1).toInt());
 
             QJsonObject jsonItem;
             jsonItem.insert("name", qApp->translate("QObject", opt->name().toUtf8().data()));
-            jsonItem.insert("value", QKeySequence(modifier + key).toString(QKeySequence::PortableText));
+            jsonItem.insert("value", QKeySequence(opt->value().toStringList().at(0)).toString(QKeySequence::PortableText));
             jsonItems.append(jsonItem);
 
         });
 
+//        if(grp->name() == "File")
+//        {
+//            QJsonObject jsonItem_space;
+//            jsonItem_space.insert("name", qApp->translate("QObject", ""));
+//            jsonItem_space.insert("value", "");
+//            jsonItems.append(jsonItem_space);
+
+//            QJsonObject jsonItem;
+//            jsonItem.insert("name", qApp->translate("QObject", "Help"));
+//            jsonItem.insert("value", "F1");
+//            jsonItems.append(jsonItem);
+
+//            QJsonObject jsonItem_show;
+//            jsonItem.insert("name", qApp->translate("QObject", "Display shortcuts"));
+//            jsonItem.insert("value", "Ctrl+Shift+?");
+//            jsonItems.append(jsonItem);
+//        }
+
         jsonGroup.insert("groupItems", jsonItems);
         jsonGroups.append(jsonGroup);
     });
+
+    QJsonObject jsonGroup;
+    jsonGroup.insert("groupName", qApp->translate("QObject", "Settings"));
+    QJsonArray jsonItems;
+    QJsonObject jsonItem;
+    jsonItem.insert("name", qApp->translate("QObject", "Help"));
+    jsonItem.insert("value", "F1");
+    jsonItems.append(jsonItem);
+
+    QJsonObject jsonItem_show;
+    jsonItem.insert("name", qApp->translate("QObject", "Display shortcuts"));
+    jsonItem.insert("value", "Ctrl+Shift+?");
+    jsonItems.append(jsonItem);
+    jsonGroup.insert("groupItems", jsonItems);
+    jsonGroups.append(jsonGroup);
+
     shortcutObj.insert("shortcut", jsonGroups);
 
     QJsonDocument doc(shortcutObj);
@@ -239,7 +311,7 @@ vector<QAction*> ShortcutManager::actionsForBindings()
         act->setProperty("origin", "shortcut");
         actions.push_back(act);
 
-        qDebug() << "action " << p.key() << p.value();
+        //qDebug() << "action " << p.key() << p.value();
         ++p;
     }
 
