@@ -68,6 +68,7 @@ private slots:
 
 signals:
     void subtitlesDownloadedFor(const QUrl& url, const QList<QString>& filenames, FailReason r);
+    void onlineSubtitleStateChanged(const FailReason reason);
 
 private:
     QString _defaultLocation;
@@ -81,7 +82,7 @@ private:
     OnlineSubtitle();
     void subtitlesDownloadComplete();
     QString findAvailableName(const QString& tmpl, int id);
-    bool hasHashConflict(const QString& path, const QString& tmpl); 
+    bool hasHashConflict(const QString& path, const QString& tmpl, QString& conflictPath);
 };
 }
 
