@@ -1,4 +1,4 @@
-/* 
+/*
  * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -28,13 +28,14 @@
  * files in the program, then also delete it here.
  */
 #include "config.h"
-
+#include <iostream>
 #include "player_engine.h"
 #include "playlist_model.h"
 #include "movie_configuration.h"
 #include "online_sub.h"
 
 #include "mpv_proxy.h"
+#include "compositing_manager.h"
 
 #ifndef _LIBDMR_
 #include "dmr_settings.h"
@@ -46,7 +47,7 @@ DCORE_USE_NAMESPACE
 namespace dmr {
 
 PlayerEngine::PlayerEngine(QWidget *parent)
-    :QWidget(parent)
+    : QWidget(parent)
 {
     auto *l = new QVBoxLayout(this);
     l->setContentsMargins(0, 0, 0, 0);
@@ -63,22 +64,28 @@ PlayerEngine::PlayerEngine(QWidget *parent)
         connect(_current, &Backend::aidChanged, this, &PlayerEngine::aidChanged);
         connect(_current, &Backend::videoSizeChanged, this, &PlayerEngine::videoSizeChanged);
         connect(_current, &Backend::notifyScreenshot, this, &PlayerEngine::notifyScreenshot);
+        connect(_current, &Backend::mpvErrorLogsChanged, this, &PlayerEngine::mpvErrorLogsChanged);
+        connect(_current, &Backend::mpvWarningLogsChanged, this, &PlayerEngine::mpvWarningLogsChanged);
+        connect(_current, &Backend::urlpause, this, &PlayerEngine::urlpause);
         l->addWidget(_current);
     }
 
+    connect(&_networkConfigMng, &QNetworkConfigurationManager::onlineStateChanged, this, &PlayerEngine::onlineStateChanged);
+
     setLayout(l);
 
+
 #ifndef _LIBDMR_
     connect(&Settings::get(), &Settings::subtitleChanged, this, &PlayerEngine::updateSubStyles);
 #endif
 
-    connect(&OnlineSubtitle::get(), &OnlineSubtitle::subtitlesDownloadedFor, 
+    connect(&OnlineSubtitle::get(), &OnlineSubtitle::subtitlesDownloadedFor,
             this, &PlayerEngine::onSubtitlesDownloaded);
     addSubSearchPath(OnlineSubtitle::get().storeLocation());
 
     _playlist = new PlaylistModel(this);
-    connect(_playlist, &PlaylistModel::asyncAppendFinished, this, 
-            &PlayerEngine::onPlaylistAsyncAppendFinished);
+    connect(_playlist, &PlaylistModel::asyncAppendFinished, this,
+            &PlayerEngine::onPlaylistAsyncAppendFinished, Qt::DirectConnection);
 }
 
 PlayerEngine::~PlayerEngine()
@@ -95,10 +102,10 @@ PlayerEngine::~PlayerEngine()
     qDebug() << __func__;
 }
 
-bool PlayerEngine::isPlayableFile(const QUrl& url)
+bool PlayerEngine::isPlayableFile(const QUrl &url)
 {
     if (url.isLocalFile()) {
-        return isPlayableFile(url.path());
+        return (isPlayableFile(url.path()) || isAudioFile(url.path()));
     } else {
         // for a networked url, there is no way to know if it's playable right now
         return true;
@@ -107,7 +114,7 @@ bool PlayerEngine::isPlayableFile(const QUrl& url)
 
 static QStringList suffixes;
 
-static const QStringList& buildPlayableDatabase()
+static const QStringList &buildPlayableDatabase()
 {
     static QStringList mimeTypes = {
         "application/ogg",
@@ -164,10 +171,18 @@ static const QStringList& buildPlayableDatabase()
     return suffixes;
 }
 
-bool PlayerEngine::isPlayableFile(const QString& name)
+bool PlayerEngine::isPlayableFile(const QString &name)
+{
+    bool bRes = true;
+    auto suffix = QString("*") + name.mid(name.lastIndexOf('.'));
+    bRes =  video_filetypes.contains(suffix, Qt::CaseInsensitive) | audio_filetypes.contains(suffix, Qt::CaseInsensitive);
+    return bRes;
+}
+
+bool PlayerEngine::isAudioFile(const QString &name)
 {
     auto suffix = QString("*") + name.mid(name.lastIndexOf('.'));
-    return video_filetypes.contains(suffix, Qt::CaseInsensitive);
+    return  audio_filetypes.contains(suffix, Qt::CaseInsensitive);
 }
 
 void PlayerEngine::updateSubStyles()
@@ -197,7 +212,7 @@ void PlayerEngine::updateSubStyles()
 
 void PlayerEngine::waitLastEnd()
 {
-    if (auto *mpv = dynamic_cast<MpvProxy*>(_current)) {
+    if (auto *mpv = dynamic_cast<MpvProxy *>(_current)) {
         mpv->pollingEndOfPlayback();
     }
 }
@@ -208,35 +223,56 @@ void PlayerEngine::onBackendStateChanged()
 
     auto old = _state;
     switch (_current->state()) {
-        case Backend::PlayState::Playing:
-            _state = CoreState::Playing;
-            break;
-        case Backend::PlayState::Paused:
-            _state = CoreState::Paused;
-            break;
-        case Backend::PlayState::Stopped:
-            _state = CoreState::Idle;
-            break;
+    case Backend::PlayState::Playing:
+        _state = CoreState::Playing;
+
+        //playing . emit thumbnail progress mode signal with setting file
+        emit siginitthumbnailseting();
+        break;
+    case Backend::PlayState::Paused:
+        _state = CoreState::Paused;
+        break;
+    case Backend::PlayState::Stopped:
+        _state = CoreState::Idle;
+        break;
     }
 
     updateSubStyles();
     if (old != _state)
         emit stateChanged();
+
+    auto systemEnv = QProcessEnvironment::systemEnvironment();
+    QString XDG_SESSION_TYPE = systemEnv.value(QStringLiteral("XDG_SESSION_TYPE"));
+    QString WAYLAND_DISPLAY = systemEnv.value(QStringLiteral("WAYLAND_DISPLAY"));
+    if (XDG_SESSION_TYPE == QLatin1String("wayland") ||
+            WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) {
+        if ( _state == CoreState::Idle) {
+            QPalette pal(qApp->palette());
+            this->setAutoFillBackground(true);
+            this->setPalette(pal);
+        } else {
+            QPalette pal(this->palette());
+            pal.setColor(QPalette::Background, Qt::black);
+            this->setAutoFillBackground(true);
+            this->setPalette(pal);
+        }
+    }
+
 }
 
 PlayerEngine::CoreState PlayerEngine::state()
 {
     auto old = _state;
     switch (_current->state()) {
-        case Backend::PlayState::Playing:
-            _state = CoreState::Playing;
-            break;
-        case Backend::PlayState::Paused:
-            _state = CoreState::Paused;
-            break;
-        case Backend::PlayState::Stopped:
-            _state = CoreState::Idle;
-            break;
+    case Backend::PlayState::Playing:
+        _state = CoreState::Playing;
+        break;
+    case Backend::PlayState::Paused:
+        _state = CoreState::Paused;
+        break;
+    case Backend::PlayState::Stopped:
+        _state = CoreState::Idle;
+        break;
     }
 
     if (old != _state) {
@@ -246,7 +282,7 @@ PlayerEngine::CoreState PlayerEngine::state()
     return _state;
 }
 
-const PlayingMovieInfo& PlayerEngine::playingMovieInfo()
+const PlayingMovieInfo &PlayerEngine::playingMovieInfo()
 {
     static PlayingMovieInfo empty;
 
@@ -256,7 +292,9 @@ const PlayingMovieInfo& PlayerEngine::playingMovieInfo()
 
 int PlayerEngine::aid()
 {
-    if (state() == CoreState::Idle) { return 0; }
+    if (state() == CoreState::Idle) {
+        return 0;
+    }
     if (!_current) return 0;
 
     return _current->aid();
@@ -264,56 +302,75 @@ int PlayerEngine::aid()
 
 int PlayerEngine::sid()
 {
-    if (state() == CoreState::Idle) { return 0; }
+    if (state() == CoreState::Idle) {
+        return 0;
+    }
     if (!_current) return 0;
 
     return _current->sid();
 }
 
-void PlayerEngine::onSubtitlesDownloaded(const QUrl& url, const QList<QString>& filenames,
-        OnlineSubtitle::FailReason reason)
+void PlayerEngine::onSubtitlesDownloaded(const QUrl &url, const QList<QString> &filenames,
+                                         OnlineSubtitle::FailReason reason)
 {
-    if (state() == CoreState::Idle) { return; }
+    if (state() == CoreState::Idle) {
+        return;
+    }
     if (!_current) return;
 
-    if (playlist().currentInfo().url != url) 
+    if (playlist().currentInfo().url != url)
         return;
 
-    emit loadOnlineSubtitlesFinished(url,
-            filenames.size() > 0 || reason == OnlineSubtitle::Duplicated);
-    for (auto& filename: filenames)
-        _current->loadSubtitle(filename);
+    bool res = false;
+
+    for (auto &filename : filenames) {
+        if ( true == _current->loadSubtitle(filename)) {
+            res = true;
+        } else {
+            QFile::remove(filename);
+        }
+    }
+
+    emit loadOnlineSubtitlesFinished(url, res);
+
 }
 
-bool PlayerEngine::loadSubtitle(const QFileInfo& fi)
+bool PlayerEngine::loadSubtitle(const QFileInfo &fi)
 {
-    if (state() == CoreState::Idle) { return true; }
+    if (state() == CoreState::Idle) {
+        return true;
+    }
     if (!_current) return true;
 
-    const auto& pmf = _current->playingMovieInfo();
+    const auto &pmf = _current->playingMovieInfo();
     auto pif = playlist().currentInfo();
-    for (const auto& sub: pmf.subs) {
+    int i = 0;
+    for (const auto &sub : pmf.subs) {
         if (sub["external"].toBool()) {
             auto path = sub["external-filename"].toString();
             if (path == fi.canonicalFilePath()) {
+                this->selectSubtitle(i);
                 return true;
             }
         }
+        ++i;
     }
 
     if (_current->loadSubtitle(fi)) {
 #ifndef _LIBDMR_
         MovieConfiguration::get().append2ListUrl(pif.url, ConfigKnownKey::ExternalSubs,
-                fi.canonicalFilePath());
+                                                 fi.canonicalFilePath());
 #endif
         return true;
     }
     return false;
 }
 
-void PlayerEngine::loadOnlineSubtitle(const QUrl& url)
+void PlayerEngine::loadOnlineSubtitle(const QUrl &url)
 {
-    if (state() == CoreState::Idle) { return; }
+    if (state() == CoreState::Idle) {
+        return;
+    }
     if (!_current) return;
 
     OnlineSubtitle::get().requestSubtitle(url);
@@ -343,7 +400,7 @@ QString PlayerEngine::subCodepage()
     return _current->subCodepage();
 }
 
-void PlayerEngine::setSubCodepage(const QString& cp)
+void PlayerEngine::setSubCodepage(const QString &cp)
 {
     if (!_current) return;
     _current->setSubCodepage(cp);
@@ -351,23 +408,23 @@ void PlayerEngine::setSubCodepage(const QString& cp)
     emit subCodepageChanged();
 }
 
-void PlayerEngine::addSubSearchPath(const QString& path)
+void PlayerEngine::addSubSearchPath(const QString &path)
 {
     if (!_current) return;
     _current->addSubSearchPath(path);
 }
 
-void PlayerEngine::updateSubStyle(const QString& font, int sz)
+void PlayerEngine::updateSubStyle(const QString &font, int sz)
 {
     if (!_current) return;
-    _current->updateSubStyle(font, sz);
+    _current->updateSubStyle(font, sz / 2);
 }
 
 void PlayerEngine::selectSubtitle(int id)
 {
     if (!_current) return;
     if (state() != CoreState::Idle) {
-        const auto& pmf = _current->playingMovieInfo();
+        const auto &pmf = _current->playingMovieInfo();
         if (id >= pmf.subs.size()) return;
         auto sid = pmf.subs[id]["id"].toInt();
         _current->selectSubtitle(sid);
@@ -376,7 +433,9 @@ void PlayerEngine::selectSubtitle(int id)
 
 bool PlayerEngine::isSubVisible()
 {
-    if (state() == CoreState::Idle) { return false; }
+    if (state() == CoreState::Idle) {
+        return false;
+    }
     if (!_current) return false;
 
     return _current->isSubVisible();
@@ -429,6 +488,7 @@ void PlayerEngine::toggleMute()
 {
     if (!_current) return;
     _current->toggleMute();
+    emit volumeChanged();
 }
 
 void PlayerEngine::savePreviousMovieState()
@@ -436,13 +496,29 @@ void PlayerEngine::savePreviousMovieState()
     savePlaybackPosition();
 }
 
-//FIXME: TODO: update _current according to file 
+void PlayerEngine::paintEvent(QPaintEvent *e)
+{
+    if (!CompositingManager::get().composited()) {
+        QRect rect = this->rect();
+        QImage icon = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
+        QPixmap pix = QPixmap::fromImage(icon);
+        int x = this->rect().center().x() - pix.width() / 2;
+        int y = this->rect().center().y() - pix.height() / 2;
+        QPainter p(this);
+
+        p.fillRect(rect, QBrush(QColor(255, 255, 255)));
+        p.drawPixmap(x, y, pix);
+    }
+    return QWidget::paintEvent(e);
+}
+
+//FIXME: TODO: update _current according to file
 void PlayerEngine::requestPlay(int id)
 {
     if (!_current) return;
     if (id >= _playlist->count()) return;
 
-    const auto& item = _playlist->items()[id];
+    const auto &item = _playlist->items()[id];
     _current->setPlayFile(item.url);
 
     DRecentData data;
@@ -479,7 +555,7 @@ void PlayerEngine::play()
 {
     if (!_current || !_playlist->count()) return;
 
-    if (state() == CoreState::Paused && 
+    if (state() == CoreState::Paused &&
             getBackendProperty("keep-open").toBool() &&
             getBackendProperty("eof-reached").toBool()) {
         stop();
@@ -507,7 +583,7 @@ void PlayerEngine::next()
     _playingRequest = false;
 }
 
-void PlayerEngine::onPlaylistAsyncAppendFinished(const QList<PlayItemInfo>& pil)
+void PlayerEngine::onPlaylistAsyncAppendFinished(const QList<PlayItemInfo> &pil)
 {
     if (_pendingPlayReq.isValid()) {
         auto id = _playlist->indexOf(_pendingPlayReq);
@@ -523,7 +599,7 @@ void PlayerEngine::onPlaylistAsyncAppendFinished(const QList<PlayItemInfo>& pil)
     }
 }
 
-void PlayerEngine::playByName(const QUrl& url)
+void PlayerEngine::playByName(const QUrl &url)
 {
     savePreviousMovieState();
     auto id = _playlist->indexOf(url);
@@ -584,6 +660,10 @@ void PlayerEngine::seekForward(int secs)
 {
     if (state() == CoreState::Idle) return;
 
+    static int lastElapsed = 0;
+
+    if (elapsed() == lastElapsed)
+        return ;
     _current->seekForward(secs);
 }
 
@@ -591,9 +671,14 @@ void PlayerEngine::seekBackward(int secs)
 {
     if (state() == CoreState::Idle) return;
 
-    _current->seekBackward(secs);
+    if (elapsed() - abs(secs) <= 0) {
+        _current->seekBackward(elapsed());
+    } else {
+        _current->seekBackward(secs);
+    }
 }
 
+
 void PlayerEngine::seekAbsolute(int pos)
 {
     if (state() == CoreState::Idle) return;
@@ -601,40 +686,52 @@ void PlayerEngine::seekAbsolute(int pos)
     _current->seekAbsolute(pos);
 }
 
-void PlayerEngine::setDVDDevice(const QString& path)
+void PlayerEngine::setDVDDevice(const QString &path)
 {
-    if (!_current) { return; }
+    if (!_current) {
+        return;
+    }
     _current->setDVDDevice(path);
 }
 
-bool PlayerEngine::addPlayFile(const QUrl& url)
+bool PlayerEngine::addPlayFile(const QUrl &url)
 {
     if (isPlayableFile(url)) {
         if (url.isLocalFile())
             _playlist->appendAsync({url});
-        else 
+        else
             _playlist->append(url);
         return true;
     }
     return false;
 }
 
-QList<QUrl> PlayerEngine::collectPlayDir(const QDir& dir)
+QList<QUrl> PlayerEngine::collectPlayDir(const QDir &dir)
 {
     QList<QUrl> urls;
+    QString strtp;
 
-    QDirIterator di(dir, QDirIterator::Subdirectories);
+    //取消递归  by thx
+    QDirIterator di(dir, QDirIterator::NoIteratorFlags);
     while (di.hasNext()) {
         di.next();
         if (di.fileInfo().isFile() && isPlayableFile(di.fileName())) {
-            urls.append(QUrl::fromLocalFile(di.filePath()));
+            strtp = di.filePath();
+            while(QFileInfo(strtp).isSymLink())
+            {
+                /*****************************
+                 * use oringnal path to replace link path
+                 * ***************************/
+               strtp = QFileInfo(strtp).symLinkTarget();
+            }
+            urls.append(QUrl::fromLocalFile(strtp));
         }
     }
 
     return urls;
 }
 
-QList<QUrl> PlayerEngine::addPlayDir(const QDir& dir)
+QList<QUrl> PlayerEngine::addPlayDir(const QDir &dir)
 {
     auto valids = collectPlayDir(dir);
     _playlist->appendAsync(valids);
@@ -642,19 +739,19 @@ QList<QUrl> PlayerEngine::addPlayDir(const QDir& dir)
 }
 
 
-QList<QUrl> PlayerEngine::addPlayFiles(const QList<QUrl>& urls)
+QList<QUrl> PlayerEngine::addPlayFiles(const QList<QUrl> &urls)
 {
     QList<QUrl> valids = collectPlayFiles(urls);
     _playlist->appendAsync(valids);
     return valids;
 }
 
-QList<QUrl> PlayerEngine::collectPlayFiles(const QList<QUrl>& urls)
+QList<QUrl> PlayerEngine::collectPlayFiles(const QList<QUrl> &urls)
 {
     qDebug() << urls;
     //NOTE: take care of loop, we don't recursive, it seems safe now
     QList<QUrl> valids;
-    for (const auto& url: urls) {
+    for (const auto &url : urls) {
         if (url.isLocalFile()) {
             QFileInfo fi(url.toLocalFile());
             if (!fi.exists()) {
@@ -667,8 +764,8 @@ QList<QUrl> PlayerEngine::collectPlayFiles(const QList<QUrl>& urls)
                 valids += subs;
                 valids += url;
                 continue;
-            } 
-            
+            }
+
             if (!url.isValid() || !isPlayableFile(url)) {
                 qDebug() << url << "not valid or playable";
                 continue;
@@ -696,7 +793,16 @@ QSize PlayerEngine::videoSize() const
 qint64 PlayerEngine::elapsed() const
 {
     if (!_current) return 0;
-    return _current->elapsed();
+    if (!_playlist) return 0;
+    if (_playlist->count() == 0) return 0;
+    if (_playlist->current() < 0) return 0;
+    qint64 nDuration = _playlist->items()[_playlist->current()].mi.duration;        //因为文件信息的持续时间和MPV返回的持续有些差别，所以，我们使用文件返回的持续时间
+    qint64 nElapsed = _current->elapsed();
+    if (nElapsed < 0 )
+        return 0;
+    if (nElapsed > nDuration)
+        return nDuration;
+    return nElapsed;
 }
 
 void PlayerEngine::setVideoAspect(double r)
@@ -719,17 +825,22 @@ int PlayerEngine::videoRotation() const
 
 void PlayerEngine::setVideoRotation(int degree)
 {
-    if (_current) 
+    if (_current)
         _current->setVideoRotation(degree);
 }
 
 void PlayerEngine::changeSoundMode(Backend::SoundMode sm)
 {
-    if (_current) 
+    if (_current)
         _current->changeSoundMode(sm);
 }
 
-void PlayerEngine::resizeEvent(QResizeEvent* re)
+void PlayerEngine::changeHwdecMode(Backend::HwdecMode hm)
+{
+    if (_current)
+        _current->changeHwdecMode(hm);
+}
+void PlayerEngine::resizeEvent(QResizeEvent *re)
 {
     bool rounded = !window()->isFullScreen() && !window()->isMaximized();
 
@@ -749,16 +860,19 @@ void PlayerEngine::resizeEvent(QResizeEvent* re)
         clearMask();
     }
 #endif
+
 }
 
-void PlayerEngine::setBackendProperty(const QString& name, const QVariant& val)
+
+
+void PlayerEngine::setBackendProperty(const QString &name, const QVariant &val)
 {
     if (_current) {
         _current->setProperty(name, val);
     }
 }
 
-QVariant PlayerEngine::getBackendProperty(const QString& name)
+QVariant PlayerEngine::getBackendProperty(const QString &name)
 {
     if (_current) {
         return _current->getProperty(name);
@@ -766,4 +880,11 @@ QVariant PlayerEngine::getBackendProperty(const QString& name)
     return QVariant();
 }
 
+void PlayerEngine::setVideoZoom(float val)
+{
+    if (_current) {
+        _current->setProperty("video-zoom", val);
+    }
+}
+
 } // end of namespace dmr
