@@ -1,4 +1,4 @@
-/* 
+/*
  * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -28,17 +28,19 @@
  * files in the program, then also delete it here.
  */
 #ifndef _DMR_PLAYLIST_MODEL_H
-#define _DMR_PLAYLIST_MODEL_H 
+#define _DMR_PLAYLIST_MODEL_H
 
 #include <QtWidgets>
 #include <QtConcurrent>
 #include <libffmpegthumbnailer/videothumbnailer.h>
 
 #include "utils.h"
-
+#include <QNetworkReply>
+#include <QMutex>
 namespace dmr {
 using namespace ffmpegthumbnailer;
 class PlayerEngine;
+class LoadThread;
 
 struct MovieInfo {
     bool valid;
@@ -54,12 +56,43 @@ struct MovieInfo {
     qint64 duration;
     int width, height;
 
-    static struct MovieInfo parseFromFile(const QFileInfo& fi, bool *ok = nullptr);
-    QString durationStr() const {
+    //3.4添加视频信息
+    //视频流信息
+    int vCodecID;
+    qint64 vCodeRate;
+    int fps;
+    float proportion;
+    //音频流信息
+    int aCodeID;
+    qint64 aCodeRate;
+    int aDigit;
+    int channels;
+    int sampling;
+
+    static struct MovieInfo parseFromFile(const QFileInfo &fi, bool *ok = nullptr);
+    QString durationStr() const
+    {
         return utils::Time2str(duration);
     }
 
-    QString sizeStr() const {
+    QString videoCodec() const
+    {
+        return  utils::videoIndex2str(vCodecID);
+    }
+
+    QString audioCodec() const
+    {
+        return utils::audioIndex2str(aCodeID);
+    }
+
+    //获取字幕编码格式（备用）
+    /*QString subtitleCodec() const
+    {
+        return utils::subtitleIndex2str();
+    }*/
+
+    QString sizeStr() const
+    {
         auto K = 1024;
         auto M = 1024 * K;
         auto G = 1024 * M;
@@ -90,7 +123,9 @@ using AppendJob = QPair<QUrl, QFileInfo>; // async job
 using PlayItemInfoList = QList<PlayItemInfo>;
 using UrlList = QList<QUrl>;
 
-class PlaylistModel: public QObject {
+
+class PlaylistModel: public QObject
+{
     Q_OBJECT
     Q_PROPERTY(int count READ count NOTIFY countChanged)
     Q_PROPERTY(int current READ current WRITE changeCurrent NOTIFY currentChanged)
@@ -110,38 +145,51 @@ public:
     PlayMode playMode() const;
     void setPlayMode(PlayMode pm);
 
-    PlaylistModel(PlayerEngine* engine);
+    PlaylistModel(PlayerEngine *engine);
     ~PlaylistModel();
 
+    qint64 getUrlFileTotalSize(QUrl url, int tryTimes) const;
+
     void clear();
     void remove(int pos);
-    void append(const QUrl&);
+    void append(const QUrl &);
 
-    void appendAsync(const QList<QUrl>&);
-    void collectionJob(const QList<QUrl>&);
+    void appendAsync(const QList<QUrl> &);
+    void collectionJob(const QList<QUrl> &);
 
     void playNext(bool fromUser);
     void playPrev(bool fromUser);
 
     int count() const;
-    const QList<PlayItemInfo>& items() const { return _infos; }
-    QList<PlayItemInfo>& items() { return _infos; }
+    const QList<PlayItemInfo> &items() const
+    {
+        return _infos;
+    }
+    QList<PlayItemInfo> &items()
+    {
+        return _infos;
+    }
 
     int current() const;
-    const PlayItemInfo& currentInfo() const;
-    PlayItemInfo& currentInfo();
-    int indexOf(const QUrl& url);
+    const PlayItemInfo &currentInfo() const;
+    PlayItemInfo &currentInfo();
+    int indexOf(const QUrl &url);
 
     void switchPosition(int p1, int p2);
 
     bool hasPendingAppends();
+    void handleAsyncAppendResults(QList<PlayItemInfo> &pil);
+    struct PlayItemInfo calculatePlayInfo(const QUrl &, const QFileInfo &fi, bool isDvd = false);
+    bool getthreadstate();
 
 public slots:
     void changeCurrent(int);
+    void delayedAppendAsync(const QList<QUrl> &);
+    void deleteThread();
 
 private slots:
     void onAsyncAppendFinished();
-    void delayedAppendAsync(const QList<QUrl>&);
+
 
 signals:
     void countChanged();
@@ -150,7 +198,7 @@ signals:
     void itemsAppended();
     void emptied();
     void playModeChanged(PlayMode);
-    void asyncAppendFinished(const QList<PlayItemInfo>&);
+    void asyncAppendFinished(const QList<PlayItemInfo> &);
     void itemInfoUpdated(int id);
 
 private:
@@ -179,16 +227,40 @@ private:
 
     QString _playlistFile;
 
-    struct PlayItemInfo calculatePlayInfo(const QUrl&, const QFileInfo& fi);
+    LoadThread *m_ploadThread;
+    QMutex *m_pdataMutex;
+    bool m_brunning;
+
     void reshuffle();
     void savePlaylist();
     void loadPlaylist();
     void clearPlaylist();
-    void appendSingle(const QUrl&);
+    void appendSingle(const QUrl &);
     void tryPlayCurrent(bool next);
-    void handleAsyncAppendResults(QList<PlayItemInfo>& pil);
+
 };
 
+
+class LoadThread: public QThread
+{
+    Q_OBJECT
+
+public:
+    LoadThread(PlaylistModel *model, const QList<QUrl> &urls);
+    ~LoadThread();
+
+public:
+    void run();
+
+private:
+    PlaylistModel *_pModel;
+    QList<QUrl> _urls;
+
+    QList<AppendJob> _pendingJob; // async job
+    QSet<QString> _urlsInJob;  // url list
+};
+
+
 }
 
 #endif /* ifndef _DMR_PLAYLIST_MODEL_H */
