@@ -1,4 +1,4 @@
-/* 
+/*
  * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -42,9 +42,10 @@ void ShowInFileManager(const QString &path)
     }
 
     QUrl url = QUrl::fromLocalFile(QFileInfo(path).dir().absolutePath());
-    QUrlQuery query;
+    //Note: The meaning of this code is unknown, use with caution
+    /*QUrlQuery query;
     query.addQueryItem("selectUrl", QUrl::fromLocalFile(path).toString());
-    url.setQuery(query);
+    url.setQuery(query);*/
 
     qDebug() << __func__ << url.toString();
 
@@ -57,9 +58,9 @@ void ShowInFileManager(const QString &path)
     if (fp->error() == QProcess::FailedToStart) {
         // Start dde-file-manager failed, try nautilus
         QDBusInterface iface("org.freedesktop.FileManager1",
-                "/org/freedesktop/FileManager1",
-                "org.freedesktop.FileManager1",
-                QDBusConnection::sessionBus());
+                             "/org/freedesktop/FileManager1",
+                             "org.freedesktop.FileManager1",
+                             QDBusConnection::sessionBus());
         if (iface.isValid()) {
             // Convert filepath to URI first.
             const QStringList uris = { QUrl::fromLocalFile(path).toString() };
@@ -78,28 +79,29 @@ void ShowInFileManager(const QString &path)
 }
 
 
-static int min(int v1, int v2, int v3) 
+static int min(int v1, int v2, int v3)
 {
     return std::min(v1, std::min(v2, v3));
 }
 
-static int stringDistance(const QString& s1, const QString& s2) {
+static int stringDistance(const QString &s1, const QString &s2)
+{
     int n = s1.size(), m = s2.size();
     if (!n || !m) return max(n, m);
 
-    vector<int> dp(n+1);
-    for (int i = 0; i < n+1; i++) dp[i] = i;
+    vector<int> dp(n + 1);
+    for (int i = 0; i < n + 1; i++) dp[i] = i;
     int pred = 0;
     int curr = 0;
 
     for (int i = 0; i < m; i++) {
         dp[0] = i;
-        pred = i+1;
+        pred = i + 1;
         for (int j = 0; j < n; j++) {
             if (s1[j] == s2[i]) {
                 curr = dp[j];
             } else {
-                curr = min(dp[j], dp[j+1], pred) + 1;
+                curr = min(dp[j], dp[j + 1], pred) + 1;
             }
             dp[j] = pred;
             pred = curr;
@@ -111,13 +113,13 @@ static int stringDistance(const QString& s1, const QString& s2) {
     return curr;
 }
 
-bool IsNamesSimilar(const QString& s1, const QString& s2)
+bool IsNamesSimilar(const QString &s1, const QString &s2)
 {
     auto dist = stringDistance(s1, s2);
     return (dist >= 0 && dist <= 4); //TODO: check ext.
 }
 
-QFileInfoList FindSimilarFiles(const QFileInfo& fi)
+QFileInfoList FindSimilarFiles(const QFileInfo &fi)
 {
     QFileInfoList fil;
 
@@ -131,19 +133,19 @@ QFileInfoList FindSimilarFiles(const QFileInfo& fi)
         if (IsNamesSimilar(fi.fileName(), it.fileInfo().fileName())) {
             fil.append(it.fileInfo());
         }
-        
+
     }
 
     //struct {
-        //bool operator()(const QFileInfo& fi1, const QFileInfo& fi2) const {
-            //return CompareNames(fi1.fileName(), fi2.fileName());
-        //}
+    //bool operator()(const QFileInfo& fi1, const QFileInfo& fi2) const {
+    //return CompareNames(fi1.fileName(), fi2.fileName());
+    //}
     //} SortByDigits;
     //std::sort(fil.begin(), fil.end(), SortByDigits);
     return fil;
 }
 
-bool CompareNames(const QString& fileName1, const QString& fileName2) 
+bool CompareNames(const QString &fileName1, const QString &fileName2)
 {
     static QRegExp rd("\\d+");
     int pos = 0;
@@ -169,7 +171,7 @@ bool CompareNames(const QString& fileName1, const QString& fileName2)
 }
 
 // hash the whole file takes amount of time, so just pick some areas to be hashed
-QString FastFileHash(const QFileInfo& fi)
+QString FastFileHash(const QFileInfo &fi)
 {
     auto sz = fi.size();
     QList<qint64> offsets = {
@@ -198,7 +200,7 @@ QString FastFileHash(const QFileInfo& fi)
 }
 
 // hash the entire file (hope file is small)
-QString FullFileHash(const QFileInfo& fi)
+QString FullFileHash(const QFileInfo &fi)
 {
     auto sz = fi.size();
 
@@ -213,6 +215,10 @@ QString FullFileHash(const QFileInfo& fi)
 
 QPixmap MakeRoundedPixmap(QPixmap pm, qreal rx, qreal ry, int rotation)
 {
+    QMatrix matrix;
+    matrix.rotate(rotation);
+    pm = pm.transformed(matrix, Qt::SmoothTransformation);
+
     auto dpr = pm.devicePixelRatio();
     QPixmap dest(pm.size());
     dest.setDevicePixelRatio(dpr);
@@ -221,17 +227,17 @@ QPixmap MakeRoundedPixmap(QPixmap pm, qreal rx, qreal ry, int rotation)
     dest.fill(Qt::transparent);
 
     QPainter p(&dest);
-    p.setRenderHints(QPainter::Antialiasing|QPainter::SmoothPixmapTransform);
+    p.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
 
     QPainterPath path;
     path.addRoundedRect(QRect(QPoint(), scaled_rect.size().toSize()), rx, ry);
     p.setClipPath(path);
 
-    QTransform transform;
-    transform.translate(scaled_rect.width()/2, scaled_rect.height()/2);
-    transform.rotate(rotation);
-    transform.translate(-scaled_rect.width()/2, -scaled_rect.height()/2);
-    p.setTransform(transform);
+//    QTransform transform;
+//    transform.translate(scaled_rect.width()/2, scaled_rect.height()/2);
+//    transform.rotate(rotation);
+//    transform.translate(-scaled_rect.width()/2, -scaled_rect.height()/2);
+//    p.setTransform(transform);
 
     p.drawPixmap(scaled_rect.toRect(), pm);
 
@@ -248,7 +254,7 @@ QPixmap MakeRoundedPixmap(QSize sz, QPixmap pm, qreal rx, qreal ry, qint64 time)
     auto scaled_rect = QRectF({0, 0}, QSizeF(dest.size() / dpr));
 
     QPainter p(&dest);
-    p.setRenderHints(QPainter::Antialiasing|QPainter::SmoothPixmapTransform);
+    p.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
 
     p.setPen(QColor(0, 0, 0, 255 / 10));
     p.drawRoundedRect(scaled_rect, rx, ry);
@@ -269,7 +275,7 @@ QPixmap MakeRoundedPixmap(QSize sz, QPixmap pm, qreal rx, qreal ry, qint64 time)
     auto tm_str = QTime(0, 0, 0).addSecs(time).toString("hh:mm:ss");
     QRect bounding = QFontMetrics(ft).boundingRect(tm_str);
     bounding.moveTopLeft({((int)(dest.width() / dpr)) - 5 - bounding.width(),
-            ((int)(dest.height() / dpr)) - 5 - bounding.height()});
+                          ((int)(dest.height() / dpr)) - 5 - bounding.height()});
 
     {
         QPainterPath pp;
@@ -336,7 +342,7 @@ void UnInhibitPower(uint32_t cookie)
     iface.call("UnInhibit", cookie);
 }
 
-void MoveToCenter(QWidget* w)
+void MoveToCenter(QWidget *w)
 {
     QDesktopWidget *dw = QApplication::desktop();
     QRect r = dw->availableGeometry(w);
@@ -351,7 +357,104 @@ QString Time2str(qint64 seconds)
     return d.toString("hh:mm:ss");
 }
 
-bool ValidateScreenshotPath(const QString& path)
+QString videoIndex2str(int index)
+{
+    QStringList videoList = {"none", "mpeg1video", "mpeg2video", "h261", "h263", "rv10", "rv20",
+                             "mjpeg", "mjpegb", "ljpeg", "sp5x", "jpegls", "mpeg4", "rawvideo", "msmpeg4v1",
+                             "msmpeg4v2", "msmpeg4v3", "wmv1", "wmv2", "h263p", "h263i", "flv1", "svq1",
+                             "svq3", "dvvideo", "huffyuv", "cyuv", "h264", "indeo3", "vp3", "theora",
+                             "asv1", "asv2", "ffv1", "4xm", "vcr1", "cljr", "mdec", "roq", "interplay_video",
+                             "xan_wc3", "xan_wc4", "rpza", "cinepak", "ws_vqa", "msrle", "msvideo1", "idcin",
+                             "8bps", "smc", "flic", "truemotion1", "vmdvideo", "mszh", "zlib", "qtrle", "tscc",
+                             "ulti", "qdraw", "vixl", "qpeg", "png", "ppm", "pbm", "pgm", "pgmyuv", "pam", "ffvhuff",
+                             "rv30", "rv40", "vc1", "wmv3", "loco", "wnv1", "aasc", "indeo2", "fraps", "truemotion2",
+                             "bmp", "cscd", "mmvideo", "zmbv", "avs", "smackvideo", "nuv", "kmvc", "flashsv",
+                             "cavs", "jpeg2000", "vmnc", "vp5", "vp6", "vp6f", "targa", "dsicinvideo", "tiertexseqvideo",
+                             "tiff", "gif", "dxa", "dnxhd", "thp", "sgi", "c93", "bethsoftvid", "ptx", "txd", "vp6a",
+                             "amv", "vb", "pcx", "sunrast", "indeo4", "indeo5", "mimic", "rl2", "escape124", "dirac", "bfi",
+                             "cmv", "motionpixels", "tgv", "tgq", "tqi", "aura", "aura2", "v210x", "tmv", "v210", "dpx",
+                             "mad", "frwu", "flashsv2", "cdgraphics", "r210", "anm", "binkvideo", "iff_ilbm", "kgv1",
+                             "yop", "vp8", "pictor", "ansi", "a64_multi", "a64_multi5", "r10k", "mxpeg", "lagarith",
+                             "prores", "jv", "dfa", "wmv3image", "vc1image", "utvideo", "bmv_video", "vble", "dxtory",
+                             "v410", "xwd", "cdxl", "xbm", "zerocodec", "mss1", "msa1", "tscc2", "mts2", "cllc", "mss2",
+                             "vp9", "aic", "escape130", "g2m", "webp", "hnm4_video", "hevc", "fic", "alias_pix",
+                             "brender_pix", "paf_video", "exr", "vp7", "sanm", "sgirle", "mvc1", "mvc2", "hqx", "tdsc",
+                             "hq_hqa", "hap", "dds", "dxv", "screenpresso", "rscc", "avs2"
+                            };
+    QStringList PCMList = {"pcm_s16le", "pcm_s16be", "pcm_u16le", "pcm_u16be", "pcm_s8", "pcm_u8", "pcm_mulaw"
+                           "pcm_alaw", "pcm_s32le", "pcm_s32be", "pcm_u32le", "pcm_u32be", "pcm_s24le", "pcm_s24be"
+                           "pcm_u24le", "pcm_u24be", "pcm_s24daud", "pcm_zork", "pcm_s16le_planar", "pcm_dvd"
+                           "pcm_f32be", "pcm_f32le", "pcm_f64be", "pcm_f64le", "pcm_bluray", "pcm_lxf", "s302m"
+                           "pcm_s8_planar", "pcm_s24le_planar", "pcm_s32le_planar", "pcm_s16be_planar"
+                          };
+    QStringList ADPCMList = {"adpcm_ima_qt", "adpcm_ima_wav", "adpcm_ima_dk3", "adpcm_ima_dk4"
+                             "adpcm_ima_ws", "adpcm_ima_smjpeg", "adpcm_ms", "adpcm_4xm", "adpcm_xa", "adpcm_adx"
+                             "adpcm_ea", "adpcm_g726", "adpcm_ct", "adpcm_swf", "adpcm_yamaha", "adpcm_sbpro_4"
+                             "adpcm_sbpro_3", "adpcm_sbpro_2", "adpcm_thp", "adpcm_ima_amv", "adpcm_ea_r1"
+                             "adpcm_ea_r3", "adpcm_ea_r2", "adpcm_ima_ea_sead", "adpcm_ima_ea_eacs", "adpcm_ea_xas"
+                             "adpcm_ea_maxis_xa", "adpcm_ima_iss", "adpcm_g722", "adpcm_ima_apc", "adpcm_vima"
+                            };
+    QStringList AMRList = {"amr_nb", "amr_wb"};
+    QStringList realAudioList = {"ra_144", "ra_288" };
+    QMap<int, QString> codecMap;
+    for (int i = 0; i < videoList.size(); i++) {
+        codecMap.insert(i, videoList[i]);
+    }
+    for (int i = 0; i < PCMList.size(); i++) {
+        codecMap.insert(i + 65536, PCMList[i]);
+    }
+    for (int i = 0; i < ADPCMList.size(); i++) {
+        codecMap.insert(i + 69632, ADPCMList[i]);
+    }
+    codecMap.insert(73728, "amr_nb");
+    codecMap.insert(73729, "amr_wb");
+    codecMap.insert(77824, "ra_144");
+    codecMap.insert(77825, "ra_288");
+    QString aa = codecMap[index];
+    return aa;
+}
+
+QString audioIndex2str(int index)
+{
+    QStringList audioList = {"mp2", "mp3", "aac", "ac3", "dts", "vorbis", "dvaudio", "wmav1", "wmav2", "mace3", "mace6",
+                             "vmdaudio", "flac", "mp3adu", "mp3on4", "shorten", "alac", "westwood_snd1", "gsm", "qdm2",
+                             "cook", "truespeech", "tta", "smackaudio", "qcelp", "wavpack", "dsicinaudio", "imc",
+                             "musepack7", "mlp", "gsm_ms", "atrac3", "ape", "nellymoser", "musepack8", "speex", "wmavoice",
+                             "wmapro", "wmalossless", "atrac3p", "eac3", "sipr", "mp1", "twinvq", "truehd", "mp4als",
+                             "atrac1", "binkaudio_rdft", "binkaudio_dct", "aac_latm", "qdmc", "celt", "g723_1", "g729",
+                             "8svx_exp", "8svx_fib", "bmv_audio", "ralf", "iac", "ilbc", "opus", "comfort_noise", "tak",
+                             "metasound", "paf_audio", "on2avc", "dss_sp", "codec2", "ffwavesynth", "sonic", "sonic_ls",
+                             "evrc", "smv", "dsd_lsbf", "dsd_msbf", "dsd_lsbf_planar", "dsd_msbf_planar", "4gv",
+                             "interplay_acm", "xma1", "xma2", "dst", "atrac3al", "atrac3pal", "dolby_e", "aptx", "aptx_hd",
+                             "sbc", "atrac9"
+                            };
+    QMap<int, QString> codecMap;
+    for (int i = 0; i < audioList.size(); i++) {
+        codecMap.insert(i + 86016, audioList[i]);
+    }
+    QString aa = codecMap[index];
+    return aa;
+}
+
+QString subtitleIndex2str(int index)
+{
+    QStringList subtitleList1 = {"dvd_subtitle", "dvb_subtitle", "text", "xsub", "ssa",
+                                 "mov_text", "hdmv_pgs_subtitle", "dvb_teletext", "srt"
+                                };
+    QStringList subtitleList2 = {"microdvd", "eia_608", "jacosub", "sami", "realtext", "stl", "subviewer1", "subviewer",
+                                 "subrip", "webvtt", "mpl2", "vplayer", "pjs", "ass", "hdmv_text_subtitle", "ttml"
+                                };
+    QMap<int, QString> codecMap;
+    for (int i = 0; i < subtitleList1.size(); i++) {
+        codecMap.insert(i + 94208, subtitleList1[i]);
+    }
+    for (int i = 0; i < subtitleList2.size(); i++) {
+        codecMap.insert(i + 96256, subtitleList2[i]);
+    }
+    return codecMap[index];
+}
+
+bool ValidateScreenshotPath(const QString &path)
 {
     auto name = path.trimmed();
     if (name.isEmpty()) return false;
@@ -374,7 +477,7 @@ bool ValidateScreenshotPath(const QString& path)
     return true;
 }
 
-QImage LoadHiDPIImage(const QString& filename)
+QImage LoadHiDPIImage(const QString &filename)
 {
     QImageReader reader(filename);
     reader.setScaledSize(reader.size() * qApp->devicePixelRatio());
@@ -383,14 +486,14 @@ QImage LoadHiDPIImage(const QString& filename)
     return img;
 }
 
-QPixmap LoadHiDPIPixmap(const QString& filename)
+QPixmap LoadHiDPIPixmap(const QString &filename)
 {
     return QPixmap::fromImage(LoadHiDPIImage(filename));
 }
 
 QString ElideText(const QString &text, const QSize &size,
-        QTextOption::WrapMode wordWrap, const QFont &font,
-        Qt::TextElideMode mode, int lineHeight, int lastLineWidth)
+                  QTextOption::WrapMode wordWrap, const QFont &font,
+                  Qt::TextElideMode mode, int lineHeight, int lastLineWidth)
 {
     int height = 0;
 
@@ -399,7 +502,7 @@ QString ElideText(const QString &text, const QSize &size,
     QFontMetrics fontMetrics(font);
 
     textLayout.setFont(font);
-    const_cast<QTextOption*>(&textLayout.textOption())->setWrapMode(wordWrap);
+    const_cast<QTextOption *>(&textLayout.textOption())->setWrapMode(wordWrap);
 
     textLayout.beginLayout();
 
@@ -408,9 +511,9 @@ QString ElideText(const QString &text, const QSize &size,
     while (line.isValid()) {
         height += lineHeight;
 
-        if(height + lineHeight >= size.height()) {
+        if (height + lineHeight >= size.height()) {
             str += fontMetrics.elidedText(text.mid(line.textStart() + line.textLength() + 1),
-                    mode, lastLineWidth);
+                                          mode, lastLineWidth);
 
             break;
         }
@@ -426,7 +529,7 @@ QString ElideText(const QString &text, const QSize &size,
 
         line = textLayout.createLine();
 
-        if(line.isValid())
+        if (line.isValid())
             str.append("\n");
     }
 
