@@ -1,4 +1,4 @@
-/* 
+/*
  * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -36,6 +36,7 @@
 #include <DMainWindow>
 #include <DApplication>
 #include <DWidgetUtil>
+#include <DApplicationSettings>
 
 #include "config.h"
 
@@ -46,37 +47,61 @@
 #include "compositing_manager.h"
 #include "utils.h"
 #include "movie_configuration.h"
+#include "vendor/movieapp.h"
+#include "vendor/presenter.h"
+#include <QSettings>
 
 DWIDGET_USE_NAMESPACE
 
 
 int main(int argc, char *argv[])
 {
-    CompositingManager::detectOpenGLEarly();
+    setenv("PULSE_PROP_media.role", "video", 1);
 
-    DApplication::loadDXcbPlugin();
+#ifdef __mips__
+    if (CompositingManager::get().composited()) {
+        CompositingManager::detectOpenGLEarly();
+        CompositingManager::detectPciID();
+    }
+#else
+    CompositingManager::detectOpenGLEarly();
+    CompositingManager::detectPciID();
+#endif
 
 #if defined(STATIC_LIB)
     DWIDGET_INIT_RESOURCE();
 #endif
 
+    DApplication::loadDXcbPlugin();
+
     DApplication app(argc, argv);
 
     // required by mpv
     setlocale(LC_NUMERIC, "C");
 
+#ifdef __mips__
+    if (CompositingManager::get().composited()) {
+        app.setAttribute(Qt::AA_UseHighDpiPixmaps);
+        // overwrite DApplication default value
+        app.setAttribute(Qt::AA_ForceRasterWidgets, false);
+    }
+#else
     app.setAttribute(Qt::AA_UseHighDpiPixmaps);
     // overwrite DApplication default value
     app.setAttribute(Qt::AA_ForceRasterWidgets, false);
+#endif
+
     app.setOrganizationName("deepin");
     app.setApplicationName("deepin-movie");
     app.setApplicationVersion(DMR_VERSION);
-    app.setProductIcon(QPixmap(":/resources/icons/logo-big.svg"));
+    app.setProductIcon(utils::LoadHiDPIPixmap(":/resources/icons/logo-big.svg"));
     app.setWindowIcon(QIcon(":/resources/icons/logo-big.svg"));
     QString acknowledgementLink = "https://www.deepin.org/acknowledgments/deepin-movie";
     app.setApplicationAcknowledgementPage(acknowledgementLink);
 
-    auto& clm = dmr::CommandLineManager::get();
+    //save theme
+    DApplicationSettings saveTheme;
+    auto &clm = dmr::CommandLineManager::get();
     clm.process(app);
 
     QStringList toOpenFiles;
@@ -85,24 +110,34 @@ int main(int argc, char *argv[])
     }
 
     app.loadTranslator();
-    app.setApplicationDisplayName(QObject::tr("Deepin Movie"));
+    app.setApplicationDisplayName(QObject::tr("Movie"));
     app.setApplicationDescription(QObject::tr(
-                "Deepin Movie is a well-designed and full-featured"
-                " video player with simple borderless design. It supports local and"
-                " streaming media play with multiple video formats."));
-
-    auto light_theme = dmr::Settings::get().internalOption("light_theme").toBool();
-    app.setTheme(light_theme ? "light": "dark");
+                                      "Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats."
+                                  ));
+//    "Deepin Movie is a well-designed and full-featured"
+//    " video player with simple borderless design. It supports local and"
+//    " streaming media play with multiple video formats."
+//    auto light_theme = dmr::Settings::get().internalOption("light_theme").toBool();
+//    app.setTheme(light_theme ? "light": "dark");
 
     if (clm.debug()) {
         Dtk::Core::DLogManager::registerConsoleAppender();
     }
     Dtk::Core::DLogManager::registerFileAppender();
-    qDebug() << "log path: " << Dtk::Core::DLogManager::getlogFilePath();
+    qInfo() << "log path: " << Dtk::Core::DLogManager::getlogFilePath();
 
     bool singleton = !dmr::Settings::get().isSet(dmr::Settings::MultipleInstance);
-    if (singleton && !app.setSingleInstance("deepinmovie")) {
-        qDebug() << "another deepin movie instance has started";
+
+    QString strUserPath = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+
+    QSharedMemory shared_memory(strUserPath + "deepinmovie");
+
+    if (shared_memory.attach()) {
+        shared_memory.detach();
+    }
+
+    if (singleton && !shared_memory.create(1)) {
+        qWarning() << "another deepin movie instance has started";
         if (!toOpenFiles.isEmpty()) {
             QDBusInterface iface("com.deepin.movie", "/", "com.deepin.movie");
             if (toOpenFiles.size() == 1) {
@@ -111,21 +146,24 @@ int main(int argc, char *argv[])
                 iface.asyncCall("openFiles", toOpenFiles);
             }
         }
-        
+
         exit(0);
     }
 
 
-    app.setWindowIcon(QIcon(":/resources/icons/logo.svg"));
-    app.setApplicationDisplayName(QObject::tr("Deepin Movie"));
+//    app.setWindowIcon(QIcon(":/resources/icons/logo.svg"));
+    app.setApplicationDisplayName(QObject::tr("Movie"));
     app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
 
+//    app.setApplicationVersion(DApplication::buildVersion("20190830"));
+    app.setApplicationVersion(DApplication::buildVersion(VERSION));
     MovieConfiguration::get().init();
 
     QRegExp url_re("\\w+://");
 
     dmr::MainWindow mw;
-    mw.setMinimumSize(QSize(528, 400));
+    Presenter *presenter = new Presenter(&mw);
+//    mw.setMinimumSize(QSize(1070, 680));
     mw.resize(850, 600);
     utils::MoveToCenter(&mw);
     mw.show();
@@ -139,8 +177,13 @@ int main(int argc, char *argv[])
     QDBusConnection::sessionBus().registerObject("/", &mw);
 
     if (!toOpenFiles.isEmpty()) {
-        mw.playList(toOpenFiles);
+        if (toOpenFiles.size() == 1) {
+            mw.play(toOpenFiles[0]);
+        } else {
+            mw.playList(toOpenFiles);
+        }
     }
     return app.exec();
+
 }
 
