@@ -1,483 +1,434 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="zh_CN">
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="88"/>
-        <location filename="../main.cpp" line="120"/>
-        <source>Deepin Movie</source>
-        <translation>深度影院</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="89"/>
-        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
-        <translation>深度影院是一款设计精良、功能全面的视频播放器，无边框简洁设计，支持多种视频格式本地播放和流媒体播放。</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="116"/>
         <source>Invalid folder</source>
         <translation>此文件夹无效</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="130"/>
         <source>Open folder</source>
         <translation>打开文件夹</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="121"/>
+        <source>Network disconnected</source>
+        <translation>网络已断开</translation>
+    </message>
+    <message>
         <source>You don&apos;t have permission to operate this folder</source>
         <translation>此文件夹没有操作权限</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="5"/>
         <source>Auto add similar files to play</source>
         <translation>自动查找相似文件连续播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="6"/>
         <source>Clear playlist when exit</source>
-        <translation>退出深度影院时清空播放列表</translation>
+        <translation>退出影院时清空播放列表</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="7"/>
         <source>Show video preview on mouseover</source>
         <translation>鼠标悬停进度条时显示预览</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="8"/>
         <source>Open a new player for each file played</source>
-        <translation>允许同时运行多个深度影院</translation>
+        <translation>允许同时运行多个影院</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="9"/>
         <source>Pause when minimized</source>
         <translation>最小化时暂停</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="10"/>
         <source>Remember playback position</source>
         <translation>自动从上次停止位置播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="11"/>
         <source>Path</source>
         <translation>保存路径</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="12"/>
         <source>Basic</source>
         <translation>基础设置</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="13"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="14"/>
-        <location filename="../common/settings_translation.cpp" line="19"/>
         <source>Screenshot</source>
         <translation>截图</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="15"/>
         <source>Shortcuts</source>
         <translation>快捷键</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="16"/>
         <source>File</source>
         <translation>文件</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="17"/>
         <source>Frame/Sound</source>
         <translation>画面/声音</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="18"/>
         <source>Playback</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="20"/>
-        <location filename="../common/settings_translation.cpp" line="21"/>
         <source>Subtitle</source>
         <translation>字幕</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="22"/>
         <source>Font Style</source>
         <translation>字体样式</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="23"/>
         <source>Restore Defaults</source>
         <translation>恢复默认</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="24"/>
         <source>Open file</source>
         <translation>打开文件</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="25"/>
         <source>Open next</source>
         <translation>打开下一个</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="26"/>
         <source>Open previous</source>
         <translation>打开上一个</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="27"/>
         <source>Mini mode</source>
         <translation>迷你模式</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="28"/>
         <source>Mute</source>
         <translation>静音</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="29"/>
         <source>Next frame</source>
         <translation>下一帧</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="30"/>
         <source>Previous frame</source>
         <translation>上一帧</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="31"/>
         <source>Volume down</source>
         <translation>减小音量</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="32"/>
         <source>Volume up</source>
         <translation>增大音量</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="33"/>
         <source>Speed up</source>
         <translation>加速播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="34"/>
         <source>Speed down</source>
         <translation>减速播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="35"/>
         <source>Fullscreen</source>
         <translation>全屏</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="36"/>
         <source>Pause/Play</source>
         <translation>暂停/播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="37"/>
         <source>Playlist</source>
         <translation>播放列表</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="38"/>
         <source>Reset speed</source>
         <translation>还原播放速度</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="39"/>
         <source>Rewind</source>
         <translation>快退</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="40"/>
         <source>Forward</source>
         <translation>快进</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="41"/>
-        <source>Burst screenshot</source>
-        <translation>连拍截图</translation>
-    </message>
-    <message>
-        <location filename="../common/settings_translation.cpp" line="42"/>
         <source>Film screenshot</source>
         <translation>影片截图</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="43"/>
         <source>0.5s backward</source>
         <translation>字幕延迟0.5秒</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="44"/>
         <source>0.5s forward</source>
         <translation>字幕提前0.5秒</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="45"/>
         <source>Font</source>
         <translation>字体</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="46"/>
-        <source>Font Size</source>
+        <source>Exit fullscreen/mini mode</source>
+        <translation>退出全屏/迷你模式</translation>
+    </message>
+    <message>
+        <source>Movie</source>
+        <translation>影院</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>设置</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>帮助</translation>
+    </message>
+    <message>
+        <source>Display shortcuts</source>
+        <translation>显示快捷键</translation>
+    </message>
+    <message>
+        <source>Delete from playlist</source>
+        <translation>从播放列表删除</translation>
+    </message>
+    <message>
+        <source>Film info</source>
+        <translation>影片信息</translation>
+    </message>
+    <message>
+        <source>Burst shooting</source>
+        <translation>连拍截图</translation>
+    </message>
+    <message>
+        <source>Size</source>
         <translation>字号</translation>
     </message>
+    <message>
+        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
+        <translation>影院是一款支持多种视频格式本地播放和流媒体播放的视频播放器。</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>确定</translation>
+    </message>
+    <message>
+        <source>Default play mode</source>
+        <translation>默认播放模式</translation>
+    </message>
+    <message>
+        <source>Show thumbnails in progress bar</source>
+        <translation>鼠标滑动进度条为胶片格式</translation>
+    </message>
 </context>
 <context>
     <name>UrlDialog</name>
     <message>
-        <location filename="../widgets/url_dialog.cpp" line="41"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="../widgets/url_dialog.cpp" line="42"/>
-        <source>Confirm</source>
-        <translation>确认</translation>
-    </message>
-    <message>
-        <location filename="../widgets/url_dialog.cpp" line="46"/>
         <source>Please enter the URL:</source>
         <translation>请输入您要播放文件的网络地址：</translation>
     </message>
+    <message>
+        <source>OK</source>
+        <translation>确定</translation>
+    </message>
 </context>
 <context>
     <name>dmr::ActionFactory</name>
     <message>
-        <location filename="../common/actions.cpp" line="84"/>
-        <location filename="../common/actions.cpp" line="269"/>
         <source>Settings</source>
         <translation>设置</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="108"/>
         <source>Fullscreen</source>
         <translation>全屏</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="110"/>
         <source>Always on Top</source>
         <translation>置顶窗口</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="284"/>
+        <source>Empty playlist</source>
+        <translation>清空播放列表</translation>
+    </message>
+    <message>
         <source>Film info</source>
-        <translation>电影信息</translation>
+        <translation>影片信息</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="82"/>
-        <location filename="../common/actions.cpp" line="102"/>
         <source>Open file</source>
         <translation>打开文件</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="83"/>
-        <location filename="../common/actions.cpp" line="103"/>
         <source>Open folder</source>
         <translation>打开文件夹</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="85"/>
-        <source>Light theme</source>
-        <translation>浅色主题</translation>
-    </message>
-    <message>
-        <location filename="../common/actions.cpp" line="104"/>
         <source>Open URL</source>
         <translation>打开URL</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="105"/>
         <source>Open CD/DVD</source>
         <translation>播放光盘</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="109"/>
         <source>Mini Mode</source>
         <translation>迷你模式</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="115"/>
         <source>Play Mode</source>
         <translation>播放模式</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="118"/>
         <source>Order Play</source>
         <translation>顺序播放</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="119"/>
         <source>Shuffle Play</source>
         <translation>随机播放</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="120"/>
         <source>Single Play</source>
         <translation>单个播放</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="121"/>
         <source>Single Loop</source>
         <translation>单个循环</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="122"/>
         <source>List Loop</source>
         <translation>列表循环</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="129"/>
         <source>Frame</source>
         <translation>画面</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="132"/>
         <source>Default</source>
         <translation>默认</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="140"/>
         <source>Clockwise</source>
         <translation>顺时针旋转</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="141"/>
         <source>Counterclockwise</source>
         <translation>逆时针旋转</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="144"/>
-        <source>Next frame</source>
-        <translation>下一帧</translation>
-    </message>
-    <message>
-        <location filename="../common/actions.cpp" line="145"/>
-        <source>Previous frame</source>
-        <translation>上一帧</translation>
-    </message>
-    <message>
-        <location filename="../common/actions.cpp" line="152"/>
         <source>Sound</source>
         <translation>声音</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="155"/>
         <source>Channel</source>
         <translation>声道</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="158"/>
         <source>Stereo</source>
         <translation>立体声</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="159"/>
         <source>Left channel</source>
         <translation>左声道</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="160"/>
         <source>Right channel</source>
         <translation>右声道</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="166"/>
         <source>Track</source>
         <translation>音轨</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="176"/>
         <source>Subtitle</source>
         <translation>字幕</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="177"/>
         <source>Load</source>
         <translation>载入字幕</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="178"/>
         <source>Online Search</source>
         <translation>查找在线字幕</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="182"/>
         <source>Select</source>
         <translation>选择字幕</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="186"/>
         <source>Hide</source>
         <translation>隐藏字幕</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="190"/>
         <source>Encodings</source>
         <translation>编码</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="258"/>
         <source>Screenshot</source>
         <translation>截图</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="259"/>
         <source>Film Screenshot</source>
-        <translation>截图</translation>
+        <translation>影片截图</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="260"/>
         <source>Burst Shooting</source>
         <translation>连拍截图</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="267"/>
         <source>Playlist</source>
         <translation>播放列表</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="268"/>
         <source>Film Info</source>
-        <translation>电影信息</translation>
+        <translation>影片信息</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="282"/>
-        <source>Clear playlist</source>
-        <translation>清空播放列表</translation>
+        <source>Delete from playlist</source>
+        <translation>从播放列表删除</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="283"/>
         <source>Display in file manager</source>
         <translation>在文件管理器中显示</translation>
     </message>
+    <message>
+        <source>Next Frame</source>
+        <translation>下一帧</translation>
+    </message>
+    <message>
+        <source>Previous Frame</source>
+        <translation>上一帧</translation>
+    </message>
+    <message>
+        <source>Go To Screenshot Folder</source>
+        <translation type="vanished">前往截图文件夹</translation>
+    </message>
+    <message>
+        <source>Open screenshot folder</source>
+        <translation>前往截图文件夹</translation>
+    </message>
 </context>
 <context>
     <name>dmr::BurstScreenshotsDialog</name>
     <message>
-        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
         <source>Duration: %1</source>
         <translation>时长：%1</translation>
     </message>
     <message>
-        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
         <source>Resolution: %1</source>
         <translation>分辨率：%1</translation>
     </message>
     <message>
-        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
         <source>Size: %1</source>
         <translation>影片大小：%1</translation>
     </message>
     <message>
-        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
@@ -485,257 +436,430 @@
 <context>
     <name>dmr::MainWindow</name>
     <message>
-        <location filename="../common/mainwindow.cpp" line="720"/>
-        <location filename="../common/mainwindow.cpp" line="1821"/>
         <source>Load successfully</source>
         <translation>载入字幕成功</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="720"/>
-        <location filename="../common/mainwindow.cpp" line="1821"/>
         <source>Load failed</source>
         <translation>载入字幕失败</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1424"/>
+        <source>Buffering...</source>
+        <translation>缓冲中...</translation>
+    </message>
+    <message>
         <source>No device found</source>
         <translation>没有发现可播放设备</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1442"/>
-        <source>Parse Failed</source>
-        <translation>解析失败</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="1449"/>
         <source>Open folder</source>
         <translation>打开文件夹</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1464"/>
-        <location filename="../common/mainwindow.cpp" line="1481"/>
-        <location filename="../common/mainwindow.cpp" line="1816"/>
-        <source>Open file</source>
-        <translation>打开文件</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="1466"/>
-        <location filename="../common/mainwindow.cpp" line="1483"/>
         <source>All videos (%1)</source>
         <translation>所有视频(%1)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1684"/>
-        <source>Muted</source>
+        <source>Stereo</source>
+        <translation>立体声</translation>
+    </message>
+    <message>
+        <source>Left channel</source>
+        <translation>左声道</translation>
+    </message>
+    <message>
+        <source>Right channel</source>
+        <translation>右声道</translation>
+    </message>
+    <message>
+        <source>Parse failed</source>
+        <translation>解析失败</translation>
+    </message>
+    <message>
+        <source>Mute</source>
         <translation>静音</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1687"/>
-        <location filename="../common/mainwindow.cpp" line="1699"/>
-        <location filename="../common/mainwindow.cpp" line="1709"/>
-        <location filename="../common/mainwindow.cpp" line="1716"/>
         <source>Volume: %1%</source>
         <translation>音量：%1%</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1781"/>
-        <location filename="../common/mainwindow.cpp" line="1789"/>
+        <source>Track: %1</source>
+        <translation>音轨：%1</translation>
+    </message>
+    <message>
         <source>Subtitle %1: %2s</source>
         <translation>字幕%1：%2秒</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1782"/>
-        <location filename="../common/mainwindow.cpp" line="1790"/>
         <source>delayed</source>
         <translation>延迟</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1782"/>
-        <location filename="../common/mainwindow.cpp" line="1790"/>
         <source>advanced</source>
         <translation>提前</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1797"/>
-        <location filename="../common/mainwindow.cpp" line="1804"/>
-        <location filename="../common/mainwindow.cpp" line="1811"/>
         <source>Speed: %1x</source>
         <translation>播放速度：%1倍</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1818"/>
         <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
         <translation>字幕文件 (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1880"/>
         <source>View</source>
         <translation>查看</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1891"/>
-        <source>Movie Screenshot</source>
-        <translation>视频截图</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="1892"/>
         <source>Saved to</source>
         <translation>保存到</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1906"/>
-        <location filename="../common/mainwindow.cpp" line="1989"/>
         <source>The screenshot is saved</source>
         <translation>截图已保存</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1906"/>
         <source>Failed to save the screenshot</source>
         <translation>截图保存失败</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="2076"/>
-        <location filename="../common/mainwindow.cpp" line="2782"/>
         <source>Invalid file: %1</source>
         <translation>无效文件：%1</translation>
     </message>
+    <message>
+        <source>No matching online subtitles</source>
+        <translation>未找到匹配的在线字幕</translation>
+    </message>
+    <message>
+        <source>Cannot open file or stream</source>
+        <translation>打开无法文件或者流</translation>
+    </message>
+    <message>
+        <source>Invalid file</source>
+        <translation>无效文件</translation>
+    </message>
+    <message>
+        <source>No video file found</source>
+        <translation>没有找到视频文件</translation>
+    </message>
+    <message>
+        <source>Open File</source>
+        <translation>打开文件</translation>
+    </message>
+    <message>
+        <source>Film screenshot</source>
+        <translation>影片截图</translation>
+    </message>
+    <message>
+        <source>Taking the screenshots, please wait...</source>
+        <translation>正在截图，请稍候...</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>确定</translation>
+    </message>
+    <message>
+        <source>Please insert a CD/DVD</source>
+        <translation>请插入CD或DVD</translation>
+    </message>
+    <message>
+        <source>Reading DVD files...</source>
+        <translation>正在读取光盘文件...</translation>
+    </message>
+    <message>
+        <source>4K video may be stuck</source>
+        <translation>播放4K视频可能会出现卡顿</translation>
+    </message>
+    <message>
+        <source>Please load the video first</source>
+        <translation>请先载入影片</translation>
+    </message>
+    <message>
+        <source>Order play</source>
+        <translation>顺序播放</translation>
+    </message>
+    <message>
+        <source>Shuffle play</source>
+        <translation>随机播放</translation>
+    </message>
+    <message>
+        <source>Single play</source>
+        <translation>单个播放</translation>
+    </message>
+    <message>
+        <source>Single loop</source>
+        <translation>单个循环</translation>
+    </message>
+    <message>
+        <source>List loop</source>
+        <translation>列表循环</translation>
+    </message>
+    <message>
+        <source>The CD/DVD has been ejected</source>
+        <translation>CD/DVD已弹出</translation>
+    </message>
+    <message>
+        <source>All videos (%2 %1)</source>
+        <translation type="vanished">所有视频(%2 %1)</translation>
+    </message>
+    <message>
+        <source>All videos (*)(%2 %1)</source>
+        <translation>所有视频 (*)(%2 %1)</translation>
+    </message>
+    <message>
+        <source>Please exit smart dock</source>
+        <translation>请退出智能停靠</translation>
+    </message>
+    <message>
+        <source>Disc eject</source>
+        <translatorcomment>光盘弹出</translatorcomment>
+        <translation type="vanished">光盘弹出</translation>
+    </message>
+    <message>
+        <source>HwdecMode = %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disc reject</source>
+        <translation>光盘弹出</translation>
+    </message>
 </context>
 <context>
     <name>dmr::MovieInfo</name>
     <message>
-        <location filename="../libdmr/playlist_model.h" line="67"/>
         <source>%1G</source>
-        <translation>%1G</translation>
+        <translation type="vanished">%1G</translation>
     </message>
     <message>
-        <location filename="../libdmr/playlist_model.h" line="69"/>
         <source>%1M</source>
-        <translation>%1M</translation>
+        <translation type="vanished">%1M</translation>
     </message>
     <message>
-        <location filename="../libdmr/playlist_model.h" line="71"/>
         <source>%1K</source>
-        <translation>%1K</translation>
+        <translation type="vanished">%1K</translation>
     </message>
     <message>
-        <location filename="../libdmr/playlist_model.h" line="73"/>
         <source>%1</source>
-        <translation>%1</translation>
+        <translation type="vanished">%1</translation>
     </message>
 </context>
 <context>
     <name>dmr::MovieInfoDialog</name>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
-        <source>File Type:</source>
-        <translation>文件类型：</translation>
+        <source>Film info</source>
+        <translation>影片信息</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
-        <source>Resolution:</source>
-        <translation>分辨率：</translation>
+        <source>Resolution</source>
+        <translation>分辨率</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
-        <source>File Size:</source>
-        <translation>文件大小：</translation>
+        <source>Duration</source>
+        <translation>时长</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
-        <source>Duration:</source>
-        <translation>媒体时长：</translation>
+        <source>Type</source>
+        <translation>文件类型</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
-        <source>File Path:</source>
-        <translation>文件路径：</translation>
+        <source>Size</source>
+        <translation>文件大小</translation>
+    </message>
+    <message>
+        <source>Path</source>
+        <translation>文件路径</translation>
+    </message>
+    <message>
+        <source>Codec info</source>
+        <translation>编码信息</translation>
+    </message>
+    <message>
+        <source>Video CodecID</source>
+        <translation>视频流信息</translation>
+    </message>
+    <message>
+        <source>Video CodeRate</source>
+        <translation>视频码率</translation>
+    </message>
+    <message>
+        <source>%1 kbps</source>
+        <translation>%1 kbps</translation>
+    </message>
+    <message>
+        <source>FPS</source>
+        <translation>视频帧率</translation>
+    </message>
+    <message>
+        <source>%1 fps</source>
+        <translation>%1 fps</translation>
+    </message>
+    <message>
+        <source>Proportion</source>
+        <translation>显示比例</translation>
+    </message>
+    <message>
+        <source>%1</source>
+        <translation>%1</translation>
+    </message>
+    <message>
+        <source>Audio info</source>
+        <translation>音频流信息</translation>
+    </message>
+    <message>
+        <source>Audio CodecID</source>
+        <translation>编码样式</translation>
+    </message>
+    <message>
+        <source>Audio CodeRate</source>
+        <translation>编码码率</translation>
+    </message>
+    <message>
+        <source>Audio digit</source>
+        <translation>音频位数</translation>
+    </message>
+    <message>
+        <source>%1 bits</source>
+        <translation>%1 bits</translation>
+    </message>
+    <message>
+        <source>Channels</source>
+        <translation>声道数</translation>
+    </message>
+    <message>
+        <source>%1 channels</source>
+        <translation>%1 声道</translation>
+    </message>
+    <message>
+        <source>Sampling</source>
+        <translation>采样数</translation>
+    </message>
+    <message>
+        <source>%1hz</source>
+        <translation>%1hz</translation>
     </message>
 </context>
 <context>
     <name>dmr::MpvProxy</name>
     <message>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1034"/>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1052"/>
-        <source>[internal]</source>
-        <translation>【内部】</translation>
+        <source>Internal</source>
+        <translation>内部</translation>
     </message>
 </context>
 <context>
     <name>dmr::PlayItemWidget</name>
     <message>
-        <location filename="../widgets/playlist_widget.cpp" line="192"/>
-        <location filename="../widgets/playlist_widget.cpp" line="227"/>
-        <location filename="../widgets/playlist_widget.cpp" line="402"/>
-        <source>File does not exist</source>
+        <source>The file does not exist</source>
         <translation>文件不存在</translation>
     </message>
 </context>
+<context>
+    <name>dmr::PlaylistWidget</name>
+    <message>
+        <source>Playlist</source>
+        <translation>播放列表</translation>
+    </message>
+    <message>
+        <source>%1 videos</source>
+        <translation>%1个视频</translation>
+    </message>
+    <message>
+        <source>Empty</source>
+        <translation>清空列表</translation>
+    </message>
+</context>
 <context>
     <name>dmr::Settings</name>
     <message>
-        <location filename="../common/dmr_settings.cpp" line="155"/>
-        <source>%1/DMovie%2.jpg</source>
-        <translation>%1/深度影院%2.jpg</translation>
+        <source>%1/Movie%2.jpg</source>
+        <translation>%1/影院%2.jpg</translation>
     </message>
     <message>
-        <location filename="../common/dmr_settings.cpp" line="161"/>
-        <source>%1/DMovie%2(%3).jpg</source>
-        <translation>%1/深度影院%2（%3）.jpg</translation>
+        <source>%1/Movie%2(%3).jpg</source>
+        <translation>%1/影院%2（%3）.jpg</translation>
+    </message>
+    <message>
+        <source>Order play</source>
+        <translation>顺序播放</translation>
+    </message>
+    <message>
+        <source>Shuffle play</source>
+        <translation>随机播放</translation>
+    </message>
+    <message>
+        <source>Single play</source>
+        <translation>单个播放</translation>
+    </message>
+    <message>
+        <source>Single loop</source>
+        <translation>单个循环</translation>
+    </message>
+    <message>
+        <source>List loop</source>
+        <translation>列表循环</translation>
     </message>
 </context>
 <context>
     <name>dmr::ToolboxProxy</name>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
         <source>Previous</source>
         <translation>上一个</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
         <source>Next</source>
         <translation>下一个</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
         <source>Subtitles</source>
         <translation>字幕</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
         <source>Playlist</source>
         <translation>播放列表</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
         <source>Fullscreen</source>
         <translation>全屏</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
         <source>Play/Pause</source>
         <translation>播放/暂停</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
+        <source>play</source>
+        <translation>播放</translation>
+    </message>
+    <message>
+        <source>prev</source>
+        <translation>上一个</translation>
+    </message>
+    <message>
+        <source>next</source>
+        <translation>下一个</translation>
+    </message>
+    <message>
+        <source>fs</source>
+        <translation>全屏</translation>
+    </message>
+    <message>
+        <source>list</source>
+        <translation>播放列表</translation>
+    </message>
+    <message>
         <source>Exit fullscreen</source>
         <translation>退出全屏</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
         <source>Pause</source>
         <translation>暂停</translation>
     </message>
+    <message>
+        <source>sub</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
