@@ -1,483 +1,430 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="zh_TW">
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="88"/>
-        <location filename="../main.cpp" line="120"/>
-        <source>Deepin Movie</source>
-        <translation>Deepin 電影</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="89"/>
-        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
-        <translation>Deepin 電影採用精美的無邊框介面設計並且功能全面，完整支援多種影片格式以及線上媒體串流。</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="116"/>
         <source>Invalid folder</source>
         <translation>無效資料夾</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="130"/>
         <source>Open folder</source>
         <translation>開啟資料夾</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="121"/>
+        <source>Network disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>You don&apos;t have permission to operate this folder</source>
         <translation>無權更動資料夾</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="5"/>
         <source>Auto add similar files to play</source>
         <translation>自動播放相似檔案</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="6"/>
         <source>Clear playlist when exit</source>
         <translation>離開後清除播放列表</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="7"/>
         <source>Show video preview on mouseover</source>
         <translation>滑鼠放到進度條時顯示預覽圖</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="8"/>
         <source>Open a new player for each file played</source>
         <translation>於新視窗開啟檔案</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="9"/>
         <source>Pause when minimized</source>
         <translation>最小化時暫停</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="10"/>
         <source>Remember playback position</source>
         <translation>記住播放位置</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="11"/>
         <source>Path</source>
         <translation>位置</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="12"/>
         <source>Basic</source>
         <translation>基本</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="13"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="14"/>
-        <location filename="../common/settings_translation.cpp" line="19"/>
         <source>Screenshot</source>
         <translation>截圖</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="15"/>
         <source>Shortcuts</source>
         <translation>快速鍵</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="16"/>
         <source>File</source>
         <translation>檔案</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="17"/>
         <source>Frame/Sound</source>
         <translation>畫格／聲音</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="18"/>
         <source>Playback</source>
         <translation>播放控制</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="20"/>
-        <location filename="../common/settings_translation.cpp" line="21"/>
         <source>Subtitle</source>
         <translation>字幕</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="22"/>
         <source>Font Style</source>
         <translation>字型樣式</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="23"/>
         <source>Restore Defaults</source>
         <translation>還原預設值</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="24"/>
         <source>Open file</source>
         <translation>開啟檔案</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="25"/>
         <source>Open next</source>
         <translation>開啟下一部</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="26"/>
         <source>Open previous</source>
         <translation>開啟上一部</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="27"/>
         <source>Mini mode</source>
         <translation>迷你模式</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="28"/>
         <source>Mute</source>
         <translation>靜音</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="29"/>
         <source>Next frame</source>
         <translation>下一畫格</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="30"/>
         <source>Previous frame</source>
         <translation>上一畫格</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="31"/>
         <source>Volume down</source>
         <translation>減小音量</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="32"/>
         <source>Volume up</source>
         <translation>音量增</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="33"/>
         <source>Speed up</source>
         <translation>加速</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="34"/>
         <source>Speed down</source>
         <translation>減速</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="35"/>
         <source>Fullscreen</source>
         <translation>全螢幕</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="36"/>
         <source>Pause/Play</source>
         <translation>暫停／播放</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="37"/>
         <source>Playlist</source>
         <translation>播放列表</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="38"/>
         <source>Reset speed</source>
         <translation>原速</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="39"/>
         <source>Rewind</source>
         <translation>後退</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="40"/>
         <source>Forward</source>
         <translation>前進</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="41"/>
-        <source>Burst screenshot</source>
-        <translation>影片預覽圖</translation>
-    </message>
-    <message>
-        <location filename="../common/settings_translation.cpp" line="42"/>
         <source>Film screenshot</source>
         <translation>影片截圖</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="43"/>
         <source>0.5s backward</source>
         <translation>後退 0.5 秒</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="44"/>
         <source>0.5s forward</source>
         <translation>前進 0.5 秒</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="45"/>
         <source>Font</source>
         <translation>字型</translation>
     </message>
     <message>
-        <location filename="../common/settings_translation.cpp" line="46"/>
-        <source>Font Size</source>
-        <translation>字型大小</translation>
+        <source>Exit fullscreen/mini mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Movie</source>
+        <translation>電影</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>設定</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>說明</translation>
+    </message>
+    <message>
+        <source>Display shortcuts</source>
+        <translation>顯示快速鍵</translation>
+    </message>
+    <message>
+        <source>Delete from playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Film info</source>
+        <translation>影片資訊</translation>
+    </message>
+    <message>
+        <source>Burst shooting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>圖示</translation>
+    </message>
+    <message>
+        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>確認</translation>
+    </message>
+    <message>
+        <source>Show thumbnails in progress bar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default play mode</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>UrlDialog</name>
     <message>
-        <location filename="../widgets/url_dialog.cpp" line="41"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="../widgets/url_dialog.cpp" line="42"/>
-        <source>Confirm</source>
-        <translation>確定</translation>
-    </message>
-    <message>
-        <location filename="../widgets/url_dialog.cpp" line="46"/>
         <source>Please enter the URL:</source>
         <translation>輸入 URL：</translation>
     </message>
+    <message>
+        <source>OK</source>
+        <translation>確認</translation>
+    </message>
 </context>
 <context>
     <name>dmr::ActionFactory</name>
     <message>
-        <location filename="../common/actions.cpp" line="84"/>
-        <location filename="../common/actions.cpp" line="269"/>
         <source>Settings</source>
         <translation>設定</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="108"/>
         <source>Fullscreen</source>
         <translation>全螢幕</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="110"/>
         <source>Always on Top</source>
         <translation>永遠置頂</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="284"/>
+        <source>Empty playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Film info</source>
         <translation>影片資訊</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="82"/>
-        <location filename="../common/actions.cpp" line="102"/>
         <source>Open file</source>
         <translation>開啟檔案</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="83"/>
-        <location filename="../common/actions.cpp" line="103"/>
         <source>Open folder</source>
         <translation>開啟資料夾</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="85"/>
-        <source>Light theme</source>
-        <translation>亮色主題</translation>
-    </message>
-    <message>
-        <location filename="../common/actions.cpp" line="104"/>
         <source>Open URL</source>
         <translation>開啟網址</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="105"/>
         <source>Open CD/DVD</source>
         <translation>開啟 CD/DVD</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="109"/>
         <source>Mini Mode</source>
         <translation>迷你模式</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="115"/>
         <source>Play Mode</source>
         <translation>播放模式</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="118"/>
         <source>Order Play</source>
         <translation>順序播放</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="119"/>
         <source>Shuffle Play</source>
         <translation>隨機播放</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="120"/>
         <source>Single Play</source>
         <translation>單獨播放</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="121"/>
         <source>Single Loop</source>
         <translation>單獨循環</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="122"/>
         <source>List Loop</source>
         <translation>列表循環</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="129"/>
         <source>Frame</source>
         <translation>畫格</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="132"/>
         <source>Default</source>
         <translation>預設</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="140"/>
         <source>Clockwise</source>
         <translation>順時針旋轉</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="141"/>
         <source>Counterclockwise</source>
         <translation>逆時針旋轉</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="144"/>
-        <source>Next frame</source>
-        <translation>下一畫格</translation>
-    </message>
-    <message>
-        <location filename="../common/actions.cpp" line="145"/>
-        <source>Previous frame</source>
-        <translation>上一畫格</translation>
-    </message>
-    <message>
-        <location filename="../common/actions.cpp" line="152"/>
         <source>Sound</source>
         <translation>聲音</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="155"/>
         <source>Channel</source>
         <translation>聲道</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="158"/>
         <source>Stereo</source>
         <translation>立體聲</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="159"/>
         <source>Left channel</source>
         <translation>左聲道</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="160"/>
         <source>Right channel</source>
         <translation>右聲道</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="166"/>
         <source>Track</source>
         <translation>音軌</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="176"/>
         <source>Subtitle</source>
         <translation>字幕</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="177"/>
         <source>Load</source>
         <translation>載入</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="178"/>
         <source>Online Search</source>
         <translation>線上搜尋</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="182"/>
         <source>Select</source>
         <translation>選擇</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="186"/>
         <source>Hide</source>
         <translation>隱藏</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="190"/>
         <source>Encodings</source>
         <translation>編碼</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="258"/>
         <source>Screenshot</source>
         <translation>截圖</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="259"/>
         <source>Film Screenshot</source>
         <translation>影片截圖</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="260"/>
         <source>Burst Shooting</source>
         <translation>影片預覽圖</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="267"/>
         <source>Playlist</source>
         <translation>播放列表</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="268"/>
         <source>Film Info</source>
         <translation>影片資訊</translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="282"/>
-        <source>Clear playlist</source>
-        <translation>清除播放列表</translation>
+        <source>Delete from playlist</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../common/actions.cpp" line="283"/>
         <source>Display in file manager</source>
         <translation>在檔案管理器中顯示</translation>
     </message>
+    <message>
+        <source>Next Frame</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previous Frame</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open screenshot folder</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dmr::BurstScreenshotsDialog</name>
     <message>
-        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
         <source>Duration: %1</source>
         <translation>長度：%1</translation>
     </message>
     <message>
-        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
         <source>Resolution: %1</source>
         <translation>解析度：%1</translation>
     </message>
     <message>
-        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
         <source>Size: %1</source>
         <translation>大小：%1</translation>
     </message>
     <message>
-        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
         <source>Save</source>
         <translation>儲存</translation>
     </message>
@@ -485,257 +432,425 @@
 <context>
     <name>dmr::MainWindow</name>
     <message>
-        <location filename="../common/mainwindow.cpp" line="720"/>
-        <location filename="../common/mainwindow.cpp" line="1821"/>
         <source>Load successfully</source>
         <translation>載入成功</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="720"/>
-        <location filename="../common/mainwindow.cpp" line="1821"/>
         <source>Load failed</source>
         <translation>載入失敗</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1424"/>
+        <source>Buffering...</source>
+        <translation>正在緩衝…</translation>
+    </message>
+    <message>
         <source>No device found</source>
         <translation>找不到裝置</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1442"/>
-        <source>Parse Failed</source>
-        <translation>解析失敗</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="1449"/>
         <source>Open folder</source>
         <translation>開啟資料夾</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1464"/>
-        <location filename="../common/mainwindow.cpp" line="1481"/>
-        <location filename="../common/mainwindow.cpp" line="1816"/>
-        <source>Open file</source>
-        <translation>開啟檔案</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="1466"/>
-        <location filename="../common/mainwindow.cpp" line="1483"/>
         <source>All videos (%1)</source>
         <translation>所有影片 (%1)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1684"/>
-        <source>Muted</source>
+        <source>Stereo</source>
+        <translation>立體聲</translation>
+    </message>
+    <message>
+        <source>Left channel</source>
+        <translation>左聲道</translation>
+    </message>
+    <message>
+        <source>Right channel</source>
+        <translation>右聲道</translation>
+    </message>
+    <message>
+        <source>Parse failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mute</source>
         <translation>靜音</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1687"/>
-        <location filename="../common/mainwindow.cpp" line="1699"/>
-        <location filename="../common/mainwindow.cpp" line="1709"/>
-        <location filename="../common/mainwindow.cpp" line="1716"/>
         <source>Volume: %1%</source>
         <translation>音量：%1%</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1781"/>
-        <location filename="../common/mainwindow.cpp" line="1789"/>
+        <source>Track: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Subtitle %1: %2s</source>
         <translation>字幕 %1：%2 秒</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1782"/>
-        <location filename="../common/mainwindow.cpp" line="1790"/>
         <source>delayed</source>
         <translation>後退</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1782"/>
-        <location filename="../common/mainwindow.cpp" line="1790"/>
         <source>advanced</source>
         <translation>前進</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1797"/>
-        <location filename="../common/mainwindow.cpp" line="1804"/>
-        <location filename="../common/mainwindow.cpp" line="1811"/>
         <source>Speed: %1x</source>
         <translation>速度：%1 倍</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1818"/>
         <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
         <translation>字幕 (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1880"/>
         <source>View</source>
         <translation>瀏覽</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1891"/>
-        <source>Movie Screenshot</source>
-        <translation>影片截圖</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="1892"/>
         <source>Saved to</source>
         <translation>儲存到</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1906"/>
-        <location filename="../common/mainwindow.cpp" line="1989"/>
         <source>The screenshot is saved</source>
         <translation>截圖已儲存</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1906"/>
         <source>Failed to save the screenshot</source>
         <translation>無法儲存螢幕截圖</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="2076"/>
-        <location filename="../common/mainwindow.cpp" line="2782"/>
         <source>Invalid file: %1</source>
         <translation>檔案無效：%1</translation>
     </message>
+    <message>
+        <source>No matching online subtitles</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot open file or stream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid file</source>
+        <translation>無效檔案</translation>
+    </message>
+    <message>
+        <source>No video file found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open File</source>
+        <translation>開啟檔案</translation>
+    </message>
+    <message>
+        <source>Film screenshot</source>
+        <translation>影片截圖</translation>
+    </message>
+    <message>
+        <source>Taking the screenshots, please wait...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>確認</translation>
+    </message>
+    <message>
+        <source>Please insert a CD/DVD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reading DVD files...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4K video may be stuck</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please load the video first</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All videos (%2 %1)</source>
+        <translation type="obsolete">所有影片 (%1) {2 %1)?}</translation>
+    </message>
+    <message>
+        <source>Order play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shuffle play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single loop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>List loop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The CD/DVD has been ejected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disc eject</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All videos (*)(%2 %1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>HwdecMode = %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please exit smart dock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dmr::MovieInfo</name>
     <message>
-        <location filename="../libdmr/playlist_model.h" line="67"/>
         <source>%1G</source>
-        <translation>%1 G</translation>
+        <translation type="vanished">%1 G</translation>
     </message>
     <message>
-        <location filename="../libdmr/playlist_model.h" line="69"/>
         <source>%1M</source>
-        <translation>%1 M</translation>
+        <translation type="vanished">%1 M</translation>
     </message>
     <message>
-        <location filename="../libdmr/playlist_model.h" line="71"/>
         <source>%1K</source>
-        <translation>%1 K</translation>
+        <translation type="vanished">%1 K</translation>
     </message>
     <message>
-        <location filename="../libdmr/playlist_model.h" line="73"/>
         <source>%1</source>
-        <translation>%1</translation>
+        <translation type="vanished">%1</translation>
     </message>
 </context>
 <context>
     <name>dmr::MovieInfoDialog</name>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
-        <source>File Type:</source>
-        <translation>檔案類型：</translation>
+        <source>Film info</source>
+        <translation>影片資訊</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
-        <source>Resolution:</source>
-        <translation>解析度：</translation>
+        <source>Resolution</source>
+        <translation>解析度</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
-        <source>File Size:</source>
-        <translation>檔案大小：</translation>
+        <source>Duration</source>
+        <translation>Duration</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
-        <source>Duration:</source>
-        <translation>影片長度：</translation>
+        <source>Type</source>
+        <translation>Type</translation>
     </message>
     <message>
-        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
-        <source>File Path:</source>
-        <translation>檔案位置：</translation>
+        <source>Size</source>
+        <translation>圖示</translation>
+    </message>
+    <message>
+        <source>Path</source>
+        <translation>位置</translation>
+    </message>
+    <message>
+        <source>Codec info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video CodecID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video CodeRate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 kbps</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FPS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 fps</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Proportion</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1</source>
+        <translation type="unfinished">%1</translation>
+    </message>
+    <message>
+        <source>Audio info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio CodecID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio CodeRate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio digit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 bits</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 channels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sampling</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1hz</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>dmr::MpvProxy</name>
     <message>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1034"/>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1052"/>
-        <source>[internal]</source>
-        <translation>[內嵌]</translation>
+        <source>Internal</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>dmr::PlayItemWidget</name>
     <message>
-        <location filename="../widgets/playlist_widget.cpp" line="192"/>
-        <location filename="../widgets/playlist_widget.cpp" line="227"/>
-        <location filename="../widgets/playlist_widget.cpp" line="402"/>
-        <source>File does not exist</source>
-        <translation>檔案不存在</translation>
+        <source>The file does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::PlaylistWidget</name>
+    <message>
+        <source>Playlist</source>
+        <translation>播放列表</translation>
+    </message>
+    <message>
+        <source>%1 videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Empty</source>
+        <translation>清空</translation>
     </message>
 </context>
 <context>
     <name>dmr::Settings</name>
     <message>
-        <location filename="../common/dmr_settings.cpp" line="155"/>
-        <source>%1/DMovie%2.jpg</source>
-        <translation>%1/Deepin 電影截圖_%2.jpg</translation>
+        <source>%1/Movie%2.jpg</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../common/dmr_settings.cpp" line="161"/>
-        <source>%1/DMovie%2(%3).jpg</source>
-        <translation>%1/Deepin 電影截圖_%2(%3).jpg</translation>
+        <source>%1/Movie%2(%3).jpg</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Order play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shuffle play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single loop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>List loop</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>dmr::ToolboxProxy</name>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
         <source>Previous</source>
         <translation>上一部</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
         <source>Next</source>
         <translation>下一部</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
         <source>Subtitles</source>
         <translation>字幕</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
         <source>Playlist</source>
         <translation>播放列表</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
         <source>Fullscreen</source>
         <translation>全螢幕</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
-        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
         <source>Play/Pause</source>
         <translation>播放／暫停</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
+        <source>play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>prev</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>next</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>fs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Exit fullscreen</source>
         <translation>結束全螢幕</translation>
     </message>
     <message>
-        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
         <source>Pause</source>
         <translation>暫停</translation>
     </message>
+    <message>
+        <source>sub</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
